#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.RightsFormItemValues import RightsFormItemValues


class ZhimaCreditEpLixinUserfillformQueryResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCreditEpLixinUserfillformQueryResponse, self).__init__()
        self._has_next = None
        self._item_list = None
        self._page_index = None
        self._page_total = None
        self._rights_id = None
        self._rights_name = None
        self._total = None

    @property
    def has_next(self):
        return self._has_next

    @has_next.setter
    def has_next(self, value):
        self._has_next = value
    @property
    def item_list(self):
        return self._item_list

    @item_list.setter
    def item_list(self, value):
        if isinstance(value, list):
            self._item_list = list()
            for i in value:
                if isinstance(i, RightsFormItemValues):
                    self._item_list.append(i)
                else:
                    self._item_list.append(RightsFormItemValues.from_alipay_dict(i))
    @property
    def page_index(self):
        return self._page_index

    @page_index.setter
    def page_index(self, value):
        self._page_index = value
    @property
    def page_total(self):
        return self._page_total

    @page_total.setter
    def page_total(self, value):
        self._page_total = value
    @property
    def rights_id(self):
        return self._rights_id

    @rights_id.setter
    def rights_id(self, value):
        self._rights_id = value
    @property
    def rights_name(self):
        return self._rights_name

    @rights_name.setter
    def rights_name(self, value):
        self._rights_name = value
    @property
    def total(self):
        return self._total

    @total.setter
    def total(self, value):
        self._total = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCreditEpLixinUserfillformQueryResponse, self).parse_response_content(response_content)
        if 'has_next' in response:
            self.has_next = response['has_next']
        if 'item_list' in response:
            self.item_list = response['item_list']
        if 'page_index' in response:
            self.page_index = response['page_index']
        if 'page_total' in response:
            self.page_total = response['page_total']
        if 'rights_id' in response:
            self.rights_id = response['rights_id']
        if 'rights_name' in response:
            self.rights_name = response['rights_name']
        if 'total' in response:
            self.total = response['total']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniMiniappFavoriteextDeleteModel(object):

    def __init__(self):
        self._biz_type = None
        self._extend_info = None
        self._mini_app_id = None
        self._open_id = None
        self._principal_biz_type = None
        self._principal_ids = None
        self._principal_type = None
        self._user_id = None

    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def extend_info(self):
        return self._extend_info

    @extend_info.setter
    def extend_info(self, value):
        self._extend_info = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def principal_biz_type(self):
        return self._principal_biz_type

    @principal_biz_type.setter
    def principal_biz_type(self, value):
        self._principal_biz_type = value
    @property
    def principal_ids(self):
        return self._principal_ids

    @principal_ids.setter
    def principal_ids(self, value):
        if isinstance(value, list):
            self._principal_ids = list()
            for i in value:
                self._principal_ids.append(i)
    @property
    def principal_type(self):
        return self._principal_type

    @principal_type.setter
    def principal_type(self, value):
        self._principal_type = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.extend_info:
            if hasattr(self.extend_info, 'to_alipay_dict'):
                params['extend_info'] = self.extend_info.to_alipay_dict()
            else:
                params['extend_info'] = self.extend_info
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.principal_biz_type:
            if hasattr(self.principal_biz_type, 'to_alipay_dict'):
                params['principal_biz_type'] = self.principal_biz_type.to_alipay_dict()
            else:
                params['principal_biz_type'] = self.principal_biz_type
        if self.principal_ids:
            if isinstance(self.principal_ids, list):
                for i in range(0, len(self.principal_ids)):
                    element = self.principal_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.principal_ids[i] = element.to_alipay_dict()
            if hasattr(self.principal_ids, 'to_alipay_dict'):
                params['principal_ids'] = self.principal_ids.to_alipay_dict()
            else:
                params['principal_ids'] = self.principal_ids
        if self.principal_type:
            if hasattr(self.principal_type, 'to_alipay_dict'):
                params['principal_type'] = self.principal_type.to_alipay_dict()
            else:
                params['principal_type'] = self.principal_type
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniMiniappFavoriteextDeleteModel()
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'extend_info' in d:
            o.extend_info = d['extend_info']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'principal_biz_type' in d:
            o.principal_biz_type = d['principal_biz_type']
        if 'principal_ids' in d:
            o.principal_ids = d['principal_ids']
        if 'principal_type' in d:
            o.principal_type = d['principal_type']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MapParameter import MapParameter
from alipay.aop.api.domain.MapParameter import MapParameter
from alipay.aop.api.domain.MultiCurrencyMoneyOpenApi import MultiCurrencyMoneyOpenApi


class ReceivableConfirmOrder(object):

    def __init__(self):
        self._ar_no = None
        self._ar_source = None
        self._begin_date = None
        self._business_recognize_ext = None
        self._calc_factor = None
        self._calc_method = None
        self._calc_period = None
        self._confirm_model = None
        self._end_date = None
        self._ext_info = None
        self._gmt_service = None
        self._inst_id = None
        self._ip_id = None
        self._ip_role_id = None
        self._out_biz_no = None
        self._pd_code = None
        self._pd_event_code = None
        self._pd_source = None
        self._receivable_amount = None
        self._receivable_type = None
        self._source = None
        self._user_source = None

    @property
    def ar_no(self):
        return self._ar_no

    @ar_no.setter
    def ar_no(self, value):
        self._ar_no = value
    @property
    def ar_source(self):
        return self._ar_source

    @ar_source.setter
    def ar_source(self, value):
        self._ar_source = value
    @property
    def begin_date(self):
        return self._begin_date

    @begin_date.setter
    def begin_date(self, value):
        self._begin_date = value
    @property
    def business_recognize_ext(self):
        return self._business_recognize_ext

    @business_recognize_ext.setter
    def business_recognize_ext(self, value):
        if isinstance(value, MapParameter):
            self._business_recognize_ext = value
        else:
            self._business_recognize_ext = MapParameter.from_alipay_dict(value)
    @property
    def calc_factor(self):
        return self._calc_factor

    @calc_factor.setter
    def calc_factor(self, value):
        self._calc_factor = value
    @property
    def calc_method(self):
        return self._calc_method

    @calc_method.setter
    def calc_method(self, value):
        self._calc_method = value
    @property
    def calc_period(self):
        return self._calc_period

    @calc_period.setter
    def calc_period(self, value):
        self._calc_period = value
    @property
    def confirm_model(self):
        return self._confirm_model

    @confirm_model.setter
    def confirm_model(self, value):
        self._confirm_model = value
    @property
    def end_date(self):
        return self._end_date

    @end_date.setter
    def end_date(self, value):
        self._end_date = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        if isinstance(value, list):
            self._ext_info = list()
            for i in value:
                if isinstance(i, MapParameter):
                    self._ext_info.append(i)
                else:
                    self._ext_info.append(MapParameter.from_alipay_dict(i))
    @property
    def gmt_service(self):
        return self._gmt_service

    @gmt_service.setter
    def gmt_service(self, value):
        self._gmt_service = value
    @property
    def inst_id(self):
        return self._inst_id

    @inst_id.setter
    def inst_id(self, value):
        self._inst_id = value
    @property
    def ip_id(self):
        return self._ip_id

    @ip_id.setter
    def ip_id(self, value):
        self._ip_id = value
    @property
    def ip_role_id(self):
        return self._ip_role_id

    @ip_role_id.setter
    def ip_role_id(self, value):
        self._ip_role_id = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def pd_code(self):
        return self._pd_code

    @pd_code.setter
    def pd_code(self, value):
        self._pd_code = value
    @property
    def pd_event_code(self):
        return self._pd_event_code

    @pd_event_code.setter
    def pd_event_code(self, value):
        self._pd_event_code = value
    @property
    def pd_source(self):
        return self._pd_source

    @pd_source.setter
    def pd_source(self, value):
        self._pd_source = value
    @property
    def receivable_amount(self):
        return self._receivable_amount

    @receivable_amount.setter
    def receivable_amount(self, value):
        if isinstance(value, MultiCurrencyMoneyOpenApi):
            self._receivable_amount = value
        else:
            self._receivable_amount = MultiCurrencyMoneyOpenApi.from_alipay_dict(value)
    @property
    def receivable_type(self):
        return self._receivable_type

    @receivable_type.setter
    def receivable_type(self, value):
        self._receivable_type = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def user_source(self):
        return self._user_source

    @user_source.setter
    def user_source(self, value):
        self._user_source = value


    def to_alipay_dict(self):
        params = dict()
        if self.ar_no:
            if hasattr(self.ar_no, 'to_alipay_dict'):
                params['ar_no'] = self.ar_no.to_alipay_dict()
            else:
                params['ar_no'] = self.ar_no
        if self.ar_source:
            if hasattr(self.ar_source, 'to_alipay_dict'):
                params['ar_source'] = self.ar_source.to_alipay_dict()
            else:
                params['ar_source'] = self.ar_source
        if self.begin_date:
            if hasattr(self.begin_date, 'to_alipay_dict'):
                params['begin_date'] = self.begin_date.to_alipay_dict()
            else:
                params['begin_date'] = self.begin_date
        if self.business_recognize_ext:
            if hasattr(self.business_recognize_ext, 'to_alipay_dict'):
                params['business_recognize_ext'] = self.business_recognize_ext.to_alipay_dict()
            else:
                params['business_recognize_ext'] = self.business_recognize_ext
        if self.calc_factor:
            if hasattr(self.calc_factor, 'to_alipay_dict'):
                params['calc_factor'] = self.calc_factor.to_alipay_dict()
            else:
                params['calc_factor'] = self.calc_factor
        if self.calc_method:
            if hasattr(self.calc_method, 'to_alipay_dict'):
                params['calc_method'] = self.calc_method.to_alipay_dict()
            else:
                params['calc_method'] = self.calc_method
        if self.calc_period:
            if hasattr(self.calc_period, 'to_alipay_dict'):
                params['calc_period'] = self.calc_period.to_alipay_dict()
            else:
                params['calc_period'] = self.calc_period
        if self.confirm_model:
            if hasattr(self.confirm_model, 'to_alipay_dict'):
                params['confirm_model'] = self.confirm_model.to_alipay_dict()
            else:
                params['confirm_model'] = self.confirm_model
        if self.end_date:
            if hasattr(self.end_date, 'to_alipay_dict'):
                params['end_date'] = self.end_date.to_alipay_dict()
            else:
                params['end_date'] = self.end_date
        if self.ext_info:
            if isinstance(self.ext_info, list):
                for i in range(0, len(self.ext_info)):
                    element = self.ext_info[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.ext_info[i] = element.to_alipay_dict()
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.gmt_service:
            if hasattr(self.gmt_service, 'to_alipay_dict'):
                params['gmt_service'] = self.gmt_service.to_alipay_dict()
            else:
                params['gmt_service'] = self.gmt_service
        if self.inst_id:
            if hasattr(self.inst_id, 'to_alipay_dict'):
                params['inst_id'] = self.inst_id.to_alipay_dict()
            else:
                params['inst_id'] = self.inst_id
        if self.ip_id:
            if hasattr(self.ip_id, 'to_alipay_dict'):
                params['ip_id'] = self.ip_id.to_alipay_dict()
            else:
                params['ip_id'] = self.ip_id
        if self.ip_role_id:
            if hasattr(self.ip_role_id, 'to_alipay_dict'):
                params['ip_role_id'] = self.ip_role_id.to_alipay_dict()
            else:
                params['ip_role_id'] = self.ip_role_id
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.pd_code:
            if hasattr(self.pd_code, 'to_alipay_dict'):
                params['pd_code'] = self.pd_code.to_alipay_dict()
            else:
                params['pd_code'] = self.pd_code
        if self.pd_event_code:
            if hasattr(self.pd_event_code, 'to_alipay_dict'):
                params['pd_event_code'] = self.pd_event_code.to_alipay_dict()
            else:
                params['pd_event_code'] = self.pd_event_code
        if self.pd_source:
            if hasattr(self.pd_source, 'to_alipay_dict'):
                params['pd_source'] = self.pd_source.to_alipay_dict()
            else:
                params['pd_source'] = self.pd_source
        if self.receivable_amount:
            if hasattr(self.receivable_amount, 'to_alipay_dict'):
                params['receivable_amount'] = self.receivable_amount.to_alipay_dict()
            else:
                params['receivable_amount'] = self.receivable_amount
        if self.receivable_type:
            if hasattr(self.receivable_type, 'to_alipay_dict'):
                params['receivable_type'] = self.receivable_type.to_alipay_dict()
            else:
                params['receivable_type'] = self.receivable_type
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.user_source:
            if hasattr(self.user_source, 'to_alipay_dict'):
                params['user_source'] = self.user_source.to_alipay_dict()
            else:
                params['user_source'] = self.user_source
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ReceivableConfirmOrder()
        if 'ar_no' in d:
            o.ar_no = d['ar_no']
        if 'ar_source' in d:
            o.ar_source = d['ar_source']
        if 'begin_date' in d:
            o.begin_date = d['begin_date']
        if 'business_recognize_ext' in d:
            o.business_recognize_ext = d['business_recognize_ext']
        if 'calc_factor' in d:
            o.calc_factor = d['calc_factor']
        if 'calc_method' in d:
            o.calc_method = d['calc_method']
        if 'calc_period' in d:
            o.calc_period = d['calc_period']
        if 'confirm_model' in d:
            o.confirm_model = d['confirm_model']
        if 'end_date' in d:
            o.end_date = d['end_date']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'gmt_service' in d:
            o.gmt_service = d['gmt_service']
        if 'inst_id' in d:
            o.inst_id = d['inst_id']
        if 'ip_id' in d:
            o.ip_id = d['ip_id']
        if 'ip_role_id' in d:
            o.ip_role_id = d['ip_role_id']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'pd_code' in d:
            o.pd_code = d['pd_code']
        if 'pd_event_code' in d:
            o.pd_event_code = d['pd_event_code']
        if 'pd_source' in d:
            o.pd_source = d['pd_source']
        if 'receivable_amount' in d:
            o.receivable_amount = d['receivable_amount']
        if 'receivable_type' in d:
            o.receivable_type = d['receivable_type']
        if 'source' in d:
            o.source = d['source']
        if 'user_source' in d:
            o.user_source = d['user_source']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PromoteItemModel(object):

    def __init__(self):
        self._brand_name = None
        self._merchant_name = None
        self._voucher_name = None

    @property
    def brand_name(self):
        return self._brand_name

    @brand_name.setter
    def brand_name(self, value):
        self._brand_name = value
    @property
    def merchant_name(self):
        return self._merchant_name

    @merchant_name.setter
    def merchant_name(self, value):
        self._merchant_name = value
    @property
    def voucher_name(self):
        return self._voucher_name

    @voucher_name.setter
    def voucher_name(self, value):
        self._voucher_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand_name:
            if hasattr(self.brand_name, 'to_alipay_dict'):
                params['brand_name'] = self.brand_name.to_alipay_dict()
            else:
                params['brand_name'] = self.brand_name
        if self.merchant_name:
            if hasattr(self.merchant_name, 'to_alipay_dict'):
                params['merchant_name'] = self.merchant_name.to_alipay_dict()
            else:
                params['merchant_name'] = self.merchant_name
        if self.voucher_name:
            if hasattr(self.voucher_name, 'to_alipay_dict'):
                params['voucher_name'] = self.voucher_name.to_alipay_dict()
            else:
                params['voucher_name'] = self.voucher_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PromoteItemModel()
        if 'brand_name' in d:
            o.brand_name = d['brand_name']
        if 'merchant_name' in d:
            o.merchant_name = d['merchant_name']
        if 'voucher_name' in d:
            o.voucher_name = d['voucher_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankCreditLoantradePayArSignModel(object):

    def __init__(self):
        self._alipay_user_id = None
        self._biz_scene = None
        self._sign_param = None
        self._site = None
        self._site_user_id = None
        self._sub_biz_scene = None

    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def biz_scene(self):
        return self._biz_scene

    @biz_scene.setter
    def biz_scene(self, value):
        self._biz_scene = value
    @property
    def sign_param(self):
        return self._sign_param

    @sign_param.setter
    def sign_param(self, value):
        self._sign_param = value
    @property
    def site(self):
        return self._site

    @site.setter
    def site(self, value):
        self._site = value
    @property
    def site_user_id(self):
        return self._site_user_id

    @site_user_id.setter
    def site_user_id(self, value):
        self._site_user_id = value
    @property
    def sub_biz_scene(self):
        return self._sub_biz_scene

    @sub_biz_scene.setter
    def sub_biz_scene(self, value):
        self._sub_biz_scene = value


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_user_id:
            if hasattr(self.alipay_user_id, 'to_alipay_dict'):
                params['alipay_user_id'] = self.alipay_user_id.to_alipay_dict()
            else:
                params['alipay_user_id'] = self.alipay_user_id
        if self.biz_scene:
            if hasattr(self.biz_scene, 'to_alipay_dict'):
                params['biz_scene'] = self.biz_scene.to_alipay_dict()
            else:
                params['biz_scene'] = self.biz_scene
        if self.sign_param:
            if hasattr(self.sign_param, 'to_alipay_dict'):
                params['sign_param'] = self.sign_param.to_alipay_dict()
            else:
                params['sign_param'] = self.sign_param
        if self.site:
            if hasattr(self.site, 'to_alipay_dict'):
                params['site'] = self.site.to_alipay_dict()
            else:
                params['site'] = self.site
        if self.site_user_id:
            if hasattr(self.site_user_id, 'to_alipay_dict'):
                params['site_user_id'] = self.site_user_id.to_alipay_dict()
            else:
                params['site_user_id'] = self.site_user_id
        if self.sub_biz_scene:
            if hasattr(self.sub_biz_scene, 'to_alipay_dict'):
                params['sub_biz_scene'] = self.sub_biz_scene.to_alipay_dict()
            else:
                params['sub_biz_scene'] = self.sub_biz_scene
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditLoantradePayArSignModel()
        if 'alipay_user_id' in d:
            o.alipay_user_id = d['alipay_user_id']
        if 'biz_scene' in d:
            o.biz_scene = d['biz_scene']
        if 'sign_param' in d:
            o.sign_param = d['sign_param']
        if 'site' in d:
            o.site = d['site']
        if 'site_user_id' in d:
            o.site_user_id = d['site_user_id']
        if 'sub_biz_scene' in d:
            o.sub_biz_scene = d['sub_biz_scene']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiCateringPosPaymodesortModifyModel(object):

    def __init__(self):
        self._pay_names = None
        self._shop_id = None

    @property
    def pay_names(self):
        return self._pay_names

    @pay_names.setter
    def pay_names(self, value):
        if isinstance(value, list):
            self._pay_names = list()
            for i in value:
                self._pay_names.append(i)
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.pay_names:
            if isinstance(self.pay_names, list):
                for i in range(0, len(self.pay_names)):
                    element = self.pay_names[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.pay_names[i] = element.to_alipay_dict()
            if hasattr(self.pay_names, 'to_alipay_dict'):
                params['pay_names'] = self.pay_names.to_alipay_dict()
            else:
                params['pay_names'] = self.pay_names
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiCateringPosPaymodesortModifyModel()
        if 'pay_names' in d:
            o.pay_names = d['pay_names']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DisplayConfig(object):

    def __init__(self):
        self._slogan = None
        self._slogan_img = None

    @property
    def slogan(self):
        return self._slogan

    @slogan.setter
    def slogan(self, value):
        self._slogan = value
    @property
    def slogan_img(self):
        return self._slogan_img

    @slogan_img.setter
    def slogan_img(self, value):
        self._slogan_img = value


    def to_alipay_dict(self):
        params = dict()
        if self.slogan:
            if hasattr(self.slogan, 'to_alipay_dict'):
                params['slogan'] = self.slogan.to_alipay_dict()
            else:
                params['slogan'] = self.slogan
        if self.slogan_img:
            if hasattr(self.slogan_img, 'to_alipay_dict'):
                params['slogan_img'] = self.slogan_img.to_alipay_dict()
            else:
                params['slogan_img'] = self.slogan_img
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DisplayConfig()
        if 'slogan' in d:
            o.slogan = d['slogan']
        if 'slogan_img' in d:
            o.slogan_img = d['slogan_img']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ChargeInstMode import ChargeInstMode


class AlipayEbppConfigChargeinstSearchResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppConfigChargeinstSearchResponse, self).__init__()
        self._charge_inst_mode_result = None

    @property
    def charge_inst_mode_result(self):
        return self._charge_inst_mode_result

    @charge_inst_mode_result.setter
    def charge_inst_mode_result(self, value):
        if isinstance(value, list):
            self._charge_inst_mode_result = list()
            for i in value:
                if isinstance(i, ChargeInstMode):
                    self._charge_inst_mode_result.append(i)
                else:
                    self._charge_inst_mode_result.append(ChargeInstMode.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayEbppConfigChargeinstSearchResponse, self).parse_response_content(response_content)
        if 'charge_inst_mode_result' in response:
            self.charge_inst_mode_result = response['charge_inst_mode_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.InsEmployee import InsEmployee
from alipay.aop.api.domain.InsCompany import InsCompany
from alipay.aop.api.domain.InsPartnerOrganization import InsPartnerOrganization


class AlipayInsSceneEmploymentPolicyBatchcreateModel(object):

    def __init__(self):
        self._batch_no = None
        self._channel = None
        self._effect_start_time = None
        self._employee_list = None
        self._insure_time = None
        self._merchant = None
        self._out_biz_no = None
        self._partner_organization = None
        self._period = None
        self._recom_flow_no = None
        self._scene_code = None

    @property
    def batch_no(self):
        return self._batch_no

    @batch_no.setter
    def batch_no(self, value):
        self._batch_no = value
    @property
    def channel(self):
        return self._channel

    @channel.setter
    def channel(self, value):
        self._channel = value
    @property
    def effect_start_time(self):
        return self._effect_start_time

    @effect_start_time.setter
    def effect_start_time(self, value):
        self._effect_start_time = value
    @property
    def employee_list(self):
        return self._employee_list

    @employee_list.setter
    def employee_list(self, value):
        if isinstance(value, list):
            self._employee_list = list()
            for i in value:
                if isinstance(i, InsEmployee):
                    self._employee_list.append(i)
                else:
                    self._employee_list.append(InsEmployee.from_alipay_dict(i))
    @property
    def insure_time(self):
        return self._insure_time

    @insure_time.setter
    def insure_time(self, value):
        self._insure_time = value
    @property
    def merchant(self):
        return self._merchant

    @merchant.setter
    def merchant(self, value):
        if isinstance(value, InsCompany):
            self._merchant = value
        else:
            self._merchant = InsCompany.from_alipay_dict(value)
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def partner_organization(self):
        return self._partner_organization

    @partner_organization.setter
    def partner_organization(self, value):
        if isinstance(value, InsPartnerOrganization):
            self._partner_organization = value
        else:
            self._partner_organization = InsPartnerOrganization.from_alipay_dict(value)
    @property
    def period(self):
        return self._period

    @period.setter
    def period(self, value):
        self._period = value
    @property
    def recom_flow_no(self):
        return self._recom_flow_no

    @recom_flow_no.setter
    def recom_flow_no(self, value):
        self._recom_flow_no = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.batch_no:
            if hasattr(self.batch_no, 'to_alipay_dict'):
                params['batch_no'] = self.batch_no.to_alipay_dict()
            else:
                params['batch_no'] = self.batch_no
        if self.channel:
            if hasattr(self.channel, 'to_alipay_dict'):
                params['channel'] = self.channel.to_alipay_dict()
            else:
                params['channel'] = self.channel
        if self.effect_start_time:
            if hasattr(self.effect_start_time, 'to_alipay_dict'):
                params['effect_start_time'] = self.effect_start_time.to_alipay_dict()
            else:
                params['effect_start_time'] = self.effect_start_time
        if self.employee_list:
            if isinstance(self.employee_list, list):
                for i in range(0, len(self.employee_list)):
                    element = self.employee_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.employee_list[i] = element.to_alipay_dict()
            if hasattr(self.employee_list, 'to_alipay_dict'):
                params['employee_list'] = self.employee_list.to_alipay_dict()
            else:
                params['employee_list'] = self.employee_list
        if self.insure_time:
            if hasattr(self.insure_time, 'to_alipay_dict'):
                params['insure_time'] = self.insure_time.to_alipay_dict()
            else:
                params['insure_time'] = self.insure_time
        if self.merchant:
            if hasattr(self.merchant, 'to_alipay_dict'):
                params['merchant'] = self.merchant.to_alipay_dict()
            else:
                params['merchant'] = self.merchant
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.partner_organization:
            if hasattr(self.partner_organization, 'to_alipay_dict'):
                params['partner_organization'] = self.partner_organization.to_alipay_dict()
            else:
                params['partner_organization'] = self.partner_organization
        if self.period:
            if hasattr(self.period, 'to_alipay_dict'):
                params['period'] = self.period.to_alipay_dict()
            else:
                params['period'] = self.period
        if self.recom_flow_no:
            if hasattr(self.recom_flow_no, 'to_alipay_dict'):
                params['recom_flow_no'] = self.recom_flow_no.to_alipay_dict()
            else:
                params['recom_flow_no'] = self.recom_flow_no
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayInsSceneEmploymentPolicyBatchcreateModel()
        if 'batch_no' in d:
            o.batch_no = d['batch_no']
        if 'channel' in d:
            o.channel = d['channel']
        if 'effect_start_time' in d:
            o.effect_start_time = d['effect_start_time']
        if 'employee_list' in d:
            o.employee_list = d['employee_list']
        if 'insure_time' in d:
            o.insure_time = d['insure_time']
        if 'merchant' in d:
            o.merchant = d['merchant']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'partner_organization' in d:
            o.partner_organization = d['partner_organization']
        if 'period' in d:
            o.period = d['period']
        if 'recom_flow_no' in d:
            o.recom_flow_no = d['recom_flow_no']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BelongGreenMerchantInfo import BelongGreenMerchantInfo
from alipay.aop.api.domain.GreenPaginator import GreenPaginator


class AlipayCommerceItemGreenenergyBatchqueryModel(object):

    def __init__(self):
        self._alipay_open_id = None
        self._alipay_uid = None
        self._belong_merchant_info = None
        self._energy_status = None
        self._paginator = None

    @property
    def alipay_open_id(self):
        return self._alipay_open_id

    @alipay_open_id.setter
    def alipay_open_id(self, value):
        self._alipay_open_id = value
    @property
    def alipay_uid(self):
        return self._alipay_uid

    @alipay_uid.setter
    def alipay_uid(self, value):
        self._alipay_uid = value
    @property
    def belong_merchant_info(self):
        return self._belong_merchant_info

    @belong_merchant_info.setter
    def belong_merchant_info(self, value):
        if isinstance(value, BelongGreenMerchantInfo):
            self._belong_merchant_info = value
        else:
            self._belong_merchant_info = BelongGreenMerchantInfo.from_alipay_dict(value)
    @property
    def energy_status(self):
        return self._energy_status

    @energy_status.setter
    def energy_status(self, value):
        self._energy_status = value
    @property
    def paginator(self):
        return self._paginator

    @paginator.setter
    def paginator(self, value):
        if isinstance(value, GreenPaginator):
            self._paginator = value
        else:
            self._paginator = GreenPaginator.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.alipay_open_id:
            if hasattr(self.alipay_open_id, 'to_alipay_dict'):
                params['alipay_open_id'] = self.alipay_open_id.to_alipay_dict()
            else:
                params['alipay_open_id'] = self.alipay_open_id
        if self.alipay_uid:
            if hasattr(self.alipay_uid, 'to_alipay_dict'):
                params['alipay_uid'] = self.alipay_uid.to_alipay_dict()
            else:
                params['alipay_uid'] = self.alipay_uid
        if self.belong_merchant_info:
            if hasattr(self.belong_merchant_info, 'to_alipay_dict'):
                params['belong_merchant_info'] = self.belong_merchant_info.to_alipay_dict()
            else:
                params['belong_merchant_info'] = self.belong_merchant_info
        if self.energy_status:
            if hasattr(self.energy_status, 'to_alipay_dict'):
                params['energy_status'] = self.energy_status.to_alipay_dict()
            else:
                params['energy_status'] = self.energy_status
        if self.paginator:
            if hasattr(self.paginator, 'to_alipay_dict'):
                params['paginator'] = self.paginator.to_alipay_dict()
            else:
                params['paginator'] = self.paginator
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceItemGreenenergyBatchqueryModel()
        if 'alipay_open_id' in d:
            o.alipay_open_id = d['alipay_open_id']
        if 'alipay_uid' in d:
            o.alipay_uid = d['alipay_uid']
        if 'belong_merchant_info' in d:
            o.belong_merchant_info = d['belong_merchant_info']
        if 'energy_status' in d:
            o.energy_status = d['energy_status']
        if 'paginator' in d:
            o.paginator = d['paginator']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SearchProductOrientedRuleOpenApi(object):

    def __init__(self):
        self._client_platform = None
        self._end_version = None
        self._start_version = None

    @property
    def client_platform(self):
        return self._client_platform

    @client_platform.setter
    def client_platform(self, value):
        self._client_platform = value
    @property
    def end_version(self):
        return self._end_version

    @end_version.setter
    def end_version(self, value):
        self._end_version = value
    @property
    def start_version(self):
        return self._start_version

    @start_version.setter
    def start_version(self, value):
        self._start_version = value


    def to_alipay_dict(self):
        params = dict()
        if self.client_platform:
            if hasattr(self.client_platform, 'to_alipay_dict'):
                params['client_platform'] = self.client_platform.to_alipay_dict()
            else:
                params['client_platform'] = self.client_platform
        if self.end_version:
            if hasattr(self.end_version, 'to_alipay_dict'):
                params['end_version'] = self.end_version.to_alipay_dict()
            else:
                params['end_version'] = self.end_version
        if self.start_version:
            if hasattr(self.start_version, 'to_alipay_dict'):
                params['start_version'] = self.start_version.to_alipay_dict()
            else:
                params['start_version'] = self.start_version
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SearchProductOrientedRuleOpenApi()
        if 'client_platform' in d:
            o.client_platform = d['client_platform']
        if 'end_version' in d:
            o.end_version = d['end_version']
        if 'start_version' in d:
            o.start_version = d['start_version']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class MybankCreditGuaranteeSelleradmittanceQueryResponse(AlipayResponse):

    def __init__(self):
        super(MybankCreditGuaranteeSelleradmittanceQueryResponse, self).__init__()
        self._is_admitted = None
        self._is_signed = None
        self._is_unsigned = None
        self._unsign_date = None

    @property
    def is_admitted(self):
        return self._is_admitted

    @is_admitted.setter
    def is_admitted(self, value):
        self._is_admitted = value
    @property
    def is_signed(self):
        return self._is_signed

    @is_signed.setter
    def is_signed(self, value):
        self._is_signed = value
    @property
    def is_unsigned(self):
        return self._is_unsigned

    @is_unsigned.setter
    def is_unsigned(self, value):
        self._is_unsigned = value
    @property
    def unsign_date(self):
        return self._unsign_date

    @unsign_date.setter
    def unsign_date(self, value):
        self._unsign_date = value

    def parse_response_content(self, response_content):
        response = super(MybankCreditGuaranteeSelleradmittanceQueryResponse, self).parse_response_content(response_content)
        if 'is_admitted' in response:
            self.is_admitted = response['is_admitted']
        if 'is_signed' in response:
            self.is_signed = response['is_signed']
        if 'is_unsigned' in response:
            self.is_unsigned = response['is_unsigned']
        if 'unsign_date' in response:
            self.unsign_date = response['unsign_date']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayFundWalletQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundWalletQueryResponse, self).__init__()
        self._identity_name = None
        self._identity_no = None
        self._out_biz_no = None
        self._user_wallet_id = None

    @property
    def identity_name(self):
        return self._identity_name

    @identity_name.setter
    def identity_name(self, value):
        self._identity_name = value
    @property
    def identity_no(self):
        return self._identity_no

    @identity_no.setter
    def identity_no(self, value):
        self._identity_no = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def user_wallet_id(self):
        return self._user_wallet_id

    @user_wallet_id.setter
    def user_wallet_id(self, value):
        self._user_wallet_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayFundWalletQueryResponse, self).parse_response_content(response_content)
        if 'identity_name' in response:
            self.identity_name = response['identity_name']
        if 'identity_no' in response:
            self.identity_no = response['identity_no']
        if 'out_biz_no' in response:
            self.out_biz_no = response['out_biz_no']
        if 'user_wallet_id' in response:
            self.user_wallet_id = response['user_wallet_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ExtendParams import ExtendParams


class AlipaySecurityProdMygetQueryModel(object):

    def __init__(self):
        self._extend_params = None
        self._phone = None

    @property
    def extend_params(self):
        return self._extend_params

    @extend_params.setter
    def extend_params(self, value):
        if isinstance(value, ExtendParams):
            self._extend_params = value
        else:
            self._extend_params = ExtendParams.from_alipay_dict(value)
    @property
    def phone(self):
        return self._phone

    @phone.setter
    def phone(self, value):
        self._phone = value


    def to_alipay_dict(self):
        params = dict()
        if self.extend_params:
            if hasattr(self.extend_params, 'to_alipay_dict'):
                params['extend_params'] = self.extend_params.to_alipay_dict()
            else:
                params['extend_params'] = self.extend_params
        if self.phone:
            if hasattr(self.phone, 'to_alipay_dict'):
                params['phone'] = self.phone.to_alipay_dict()
            else:
                params['phone'] = self.phone
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipaySecurityProdMygetQueryModel()
        if 'extend_params' in d:
            o.extend_params = d['extend_params']
        if 'phone' in d:
            o.phone = d['phone']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AdvertItem import AdvertItem


class Advert(object):

    def __init__(self):
        self._advert_group = None
        self._advert_id = None
        self._advert_items = None
        self._group_id = None
        self._mobile_client_type = None

    @property
    def advert_group(self):
        return self._advert_group

    @advert_group.setter
    def advert_group(self, value):
        self._advert_group = value
    @property
    def advert_id(self):
        return self._advert_id

    @advert_id.setter
    def advert_id(self, value):
        self._advert_id = value
    @property
    def advert_items(self):
        return self._advert_items

    @advert_items.setter
    def advert_items(self, value):
        if isinstance(value, list):
            self._advert_items = list()
            for i in value:
                if isinstance(i, AdvertItem):
                    self._advert_items.append(i)
                else:
                    self._advert_items.append(AdvertItem.from_alipay_dict(i))
    @property
    def group_id(self):
        return self._group_id

    @group_id.setter
    def group_id(self, value):
        self._group_id = value
    @property
    def mobile_client_type(self):
        return self._mobile_client_type

    @mobile_client_type.setter
    def mobile_client_type(self, value):
        self._mobile_client_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.advert_group:
            if hasattr(self.advert_group, 'to_alipay_dict'):
                params['advert_group'] = self.advert_group.to_alipay_dict()
            else:
                params['advert_group'] = self.advert_group
        if self.advert_id:
            if hasattr(self.advert_id, 'to_alipay_dict'):
                params['advert_id'] = self.advert_id.to_alipay_dict()
            else:
                params['advert_id'] = self.advert_id
        if self.advert_items:
            if isinstance(self.advert_items, list):
                for i in range(0, len(self.advert_items)):
                    element = self.advert_items[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.advert_items[i] = element.to_alipay_dict()
            if hasattr(self.advert_items, 'to_alipay_dict'):
                params['advert_items'] = self.advert_items.to_alipay_dict()
            else:
                params['advert_items'] = self.advert_items
        if self.group_id:
            if hasattr(self.group_id, 'to_alipay_dict'):
                params['group_id'] = self.group_id.to_alipay_dict()
            else:
                params['group_id'] = self.group_id
        if self.mobile_client_type:
            if hasattr(self.mobile_client_type, 'to_alipay_dict'):
                params['mobile_client_type'] = self.mobile_client_type.to_alipay_dict()
            else:
                params['mobile_client_type'] = self.mobile_client_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = Advert()
        if 'advert_group' in d:
            o.advert_group = d['advert_group']
        if 'advert_id' in d:
            o.advert_id = d['advert_id']
        if 'advert_items' in d:
            o.advert_items = d['advert_items']
        if 'group_id' in d:
            o.group_id = d['group_id']
        if 'mobile_client_type' in d:
            o.mobile_client_type = d['mobile_client_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingActivityUserQueryvoucherModel(object):

    def __init__(self):
        self._activity_id = None
        self._merchant_access_mode = None
        self._merchant_id = None
        self._open_id = None
        self._user_id = None
        self._voucher_code = None
        self._voucher_id = None

    @property
    def activity_id(self):
        return self._activity_id

    @activity_id.setter
    def activity_id(self, value):
        self._activity_id = value
    @property
    def merchant_access_mode(self):
        return self._merchant_access_mode

    @merchant_access_mode.setter
    def merchant_access_mode(self, value):
        self._merchant_access_mode = value
    @property
    def merchant_id(self):
        return self._merchant_id

    @merchant_id.setter
    def merchant_id(self, value):
        self._merchant_id = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def voucher_code(self):
        return self._voucher_code

    @voucher_code.setter
    def voucher_code(self, value):
        self._voucher_code = value
    @property
    def voucher_id(self):
        return self._voucher_id

    @voucher_id.setter
    def voucher_id(self, value):
        self._voucher_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.activity_id:
            if hasattr(self.activity_id, 'to_alipay_dict'):
                params['activity_id'] = self.activity_id.to_alipay_dict()
            else:
                params['activity_id'] = self.activity_id
        if self.merchant_access_mode:
            if hasattr(self.merchant_access_mode, 'to_alipay_dict'):
                params['merchant_access_mode'] = self.merchant_access_mode.to_alipay_dict()
            else:
                params['merchant_access_mode'] = self.merchant_access_mode
        if self.merchant_id:
            if hasattr(self.merchant_id, 'to_alipay_dict'):
                params['merchant_id'] = self.merchant_id.to_alipay_dict()
            else:
                params['merchant_id'] = self.merchant_id
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.voucher_code:
            if hasattr(self.voucher_code, 'to_alipay_dict'):
                params['voucher_code'] = self.voucher_code.to_alipay_dict()
            else:
                params['voucher_code'] = self.voucher_code
        if self.voucher_id:
            if hasattr(self.voucher_id, 'to_alipay_dict'):
                params['voucher_id'] = self.voucher_id.to_alipay_dict()
            else:
                params['voucher_id'] = self.voucher_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingActivityUserQueryvoucherModel()
        if 'activity_id' in d:
            o.activity_id = d['activity_id']
        if 'merchant_access_mode' in d:
            o.merchant_access_mode = d['merchant_access_mode']
        if 'merchant_id' in d:
            o.merchant_id = d['merchant_id']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'voucher_code' in d:
            o.voucher_code = d['voucher_code']
        if 'voucher_id' in d:
            o.voucher_id = d['voucher_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportWorldCarddataApplyModel(object):

    def __init__(self):
        self._biz_id = None
        self._card_no = None
        self._card_type = None
        self._client_gencode_sdkversion = None
        self._ext_info = None
        self._source = None
        self._user_id = None

    @property
    def biz_id(self):
        return self._biz_id

    @biz_id.setter
    def biz_id(self, value):
        self._biz_id = value
    @property
    def card_no(self):
        return self._card_no

    @card_no.setter
    def card_no(self, value):
        self._card_no = value
    @property
    def card_type(self):
        return self._card_type

    @card_type.setter
    def card_type(self, value):
        self._card_type = value
    @property
    def client_gencode_sdkversion(self):
        return self._client_gencode_sdkversion

    @client_gencode_sdkversion.setter
    def client_gencode_sdkversion(self, value):
        self._client_gencode_sdkversion = value
    @property
    def ext_info(self):
        return self._ext_info

    @ext_info.setter
    def ext_info(self, value):
        self._ext_info = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_id:
            if hasattr(self.biz_id, 'to_alipay_dict'):
                params['biz_id'] = self.biz_id.to_alipay_dict()
            else:
                params['biz_id'] = self.biz_id
        if self.card_no:
            if hasattr(self.card_no, 'to_alipay_dict'):
                params['card_no'] = self.card_no.to_alipay_dict()
            else:
                params['card_no'] = self.card_no
        if self.card_type:
            if hasattr(self.card_type, 'to_alipay_dict'):
                params['card_type'] = self.card_type.to_alipay_dict()
            else:
                params['card_type'] = self.card_type
        if self.client_gencode_sdkversion:
            if hasattr(self.client_gencode_sdkversion, 'to_alipay_dict'):
                params['client_gencode_sdkversion'] = self.client_gencode_sdkversion.to_alipay_dict()
            else:
                params['client_gencode_sdkversion'] = self.client_gencode_sdkversion
        if self.ext_info:
            if hasattr(self.ext_info, 'to_alipay_dict'):
                params['ext_info'] = self.ext_info.to_alipay_dict()
            else:
                params['ext_info'] = self.ext_info
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportWorldCarddataApplyModel()
        if 'biz_id' in d:
            o.biz_id = d['biz_id']
        if 'card_no' in d:
            o.card_no = d['card_no']
        if 'card_type' in d:
            o.card_type = d['card_type']
        if 'client_gencode_sdkversion' in d:
            o.client_gencode_sdkversion = d['client_gencode_sdkversion']
        if 'ext_info' in d:
            o.ext_info = d['ext_info']
        if 'source' in d:
            o.source = d['source']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class JsonOpenApiVO(object):

    def __init__(self):
        self._err_msg = None
        self._success = None

    @property
    def err_msg(self):
        return self._err_msg

    @err_msg.setter
    def err_msg(self, value):
        self._err_msg = value
    @property
    def success(self):
        return self._success

    @success.setter
    def success(self, value):
        self._success = value


    def to_alipay_dict(self):
        params = dict()
        if self.err_msg:
            if hasattr(self.err_msg, 'to_alipay_dict'):
                params['err_msg'] = self.err_msg.to_alipay_dict()
            else:
                params['err_msg'] = self.err_msg
        if self.success:
            if hasattr(self.success, 'to_alipay_dict'):
                params['success'] = self.success.to_alipay_dict()
            else:
                params['success'] = self.success
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = JsonOpenApiVO()
        if 'err_msg' in d:
            o.err_msg = d['err_msg']
        if 'success' in d:
            o.success = d['success']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.KVObj import KVObj
from alipay.aop.api.domain.NimitzPageCond import NimitzPageCond
from alipay.aop.api.domain.NimitzRangeCond import NimitzRangeCond


class DatasetRequest(object):

    def __init__(self):
        self._fields = None
        self._individual_dim_keys = None
        self._obj_dim_keys = None
        self._page_cond = None
        self._range_cond = None
        self._reversed = None
        self._rs_dataset = None

    @property
    def fields(self):
        return self._fields

    @fields.setter
    def fields(self, value):
        if isinstance(value, list):
            self._fields = list()
            for i in value:
                self._fields.append(i)
    @property
    def individual_dim_keys(self):
        return self._individual_dim_keys

    @individual_dim_keys.setter
    def individual_dim_keys(self, value):
        if isinstance(value, list):
            self._individual_dim_keys = list()
            for i in value:
                if isinstance(i, KVObj):
                    self._individual_dim_keys.append(i)
                else:
                    self._individual_dim_keys.append(KVObj.from_alipay_dict(i))
    @property
    def obj_dim_keys(self):
        return self._obj_dim_keys

    @obj_dim_keys.setter
    def obj_dim_keys(self, value):
        if isinstance(value, list):
            self._obj_dim_keys = list()
            for i in value:
                self._obj_dim_keys.append(i)
    @property
    def page_cond(self):
        return self._page_cond

    @page_cond.setter
    def page_cond(self, value):
        if isinstance(value, NimitzPageCond):
            self._page_cond = value
        else:
            self._page_cond = NimitzPageCond.from_alipay_dict(value)
    @property
    def range_cond(self):
        return self._range_cond

    @range_cond.setter
    def range_cond(self, value):
        if isinstance(value, NimitzRangeCond):
            self._range_cond = value
        else:
            self._range_cond = NimitzRangeCond.from_alipay_dict(value)
    @property
    def reversed(self):
        return self._reversed

    @reversed.setter
    def reversed(self, value):
        self._reversed = value
    @property
    def rs_dataset(self):
        return self._rs_dataset

    @rs_dataset.setter
    def rs_dataset(self, value):
        self._rs_dataset = value


    def to_alipay_dict(self):
        params = dict()
        if self.fields:
            if isinstance(self.fields, list):
                for i in range(0, len(self.fields)):
                    element = self.fields[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.fields[i] = element.to_alipay_dict()
            if hasattr(self.fields, 'to_alipay_dict'):
                params['fields'] = self.fields.to_alipay_dict()
            else:
                params['fields'] = self.fields
        if self.individual_dim_keys:
            if isinstance(self.individual_dim_keys, list):
                for i in range(0, len(self.individual_dim_keys)):
                    element = self.individual_dim_keys[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.individual_dim_keys[i] = element.to_alipay_dict()
            if hasattr(self.individual_dim_keys, 'to_alipay_dict'):
                params['individual_dim_keys'] = self.individual_dim_keys.to_alipay_dict()
            else:
                params['individual_dim_keys'] = self.individual_dim_keys
        if self.obj_dim_keys:
            if isinstance(self.obj_dim_keys, list):
                for i in range(0, len(self.obj_dim_keys)):
                    element = self.obj_dim_keys[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.obj_dim_keys[i] = element.to_alipay_dict()
            if hasattr(self.obj_dim_keys, 'to_alipay_dict'):
                params['obj_dim_keys'] = self.obj_dim_keys.to_alipay_dict()
            else:
                params['obj_dim_keys'] = self.obj_dim_keys
        if self.page_cond:
            if hasattr(self.page_cond, 'to_alipay_dict'):
                params['page_cond'] = self.page_cond.to_alipay_dict()
            else:
                params['page_cond'] = self.page_cond
        if self.range_cond:
            if hasattr(self.range_cond, 'to_alipay_dict'):
                params['range_cond'] = self.range_cond.to_alipay_dict()
            else:
                params['range_cond'] = self.range_cond
        if self.reversed:
            if hasattr(self.reversed, 'to_alipay_dict'):
                params['reversed'] = self.reversed.to_alipay_dict()
            else:
                params['reversed'] = self.reversed
        if self.rs_dataset:
            if hasattr(self.rs_dataset, 'to_alipay_dict'):
                params['rs_dataset'] = self.rs_dataset.to_alipay_dict()
            else:
                params['rs_dataset'] = self.rs_dataset
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DatasetRequest()
        if 'fields' in d:
            o.fields = d['fields']
        if 'individual_dim_keys' in d:
            o.individual_dim_keys = d['individual_dim_keys']
        if 'obj_dim_keys' in d:
            o.obj_dim_keys = d['obj_dim_keys']
        if 'page_cond' in d:
            o.page_cond = d['page_cond']
        if 'range_cond' in d:
            o.range_cond = d['range_cond']
        if 'reversed' in d:
            o.reversed = d['reversed']
        if 'rs_dataset' in d:
            o.rs_dataset = d['rs_dataset']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OpenApiAwardInfo(object):

    def __init__(self):
        self._current_award = None
        self._detail_list = None
        self._total_award = None

    @property
    def current_award(self):
        return self._current_award

    @current_award.setter
    def current_award(self, value):
        self._current_award = value
    @property
    def detail_list(self):
        return self._detail_list

    @detail_list.setter
    def detail_list(self, value):
        if isinstance(value, list):
            self._detail_list = list()
            for i in value:
                self._detail_list.append(i)
    @property
    def total_award(self):
        return self._total_award

    @total_award.setter
    def total_award(self, value):
        self._total_award = value


    def to_alipay_dict(self):
        params = dict()
        if self.current_award:
            if hasattr(self.current_award, 'to_alipay_dict'):
                params['current_award'] = self.current_award.to_alipay_dict()
            else:
                params['current_award'] = self.current_award
        if self.detail_list:
            if isinstance(self.detail_list, list):
                for i in range(0, len(self.detail_list)):
                    element = self.detail_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.detail_list[i] = element.to_alipay_dict()
            if hasattr(self.detail_list, 'to_alipay_dict'):
                params['detail_list'] = self.detail_list.to_alipay_dict()
            else:
                params['detail_list'] = self.detail_list
        if self.total_award:
            if hasattr(self.total_award, 'to_alipay_dict'):
                params['total_award'] = self.total_award.to_alipay_dict()
            else:
                params['total_award'] = self.total_award
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OpenApiAwardInfo()
        if 'current_award' in d:
            o.current_award = d['current_award']
        if 'detail_list' in d:
            o.detail_list = d['detail_list']
        if 'total_award' in d:
            o.total_award = d['total_award']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.TestDemoWzw import TestDemoWzw


class AlipayOpenOperationOpenbizmockTestQueryModel(object):

    def __init__(self):
        self._fuza = None
        self._out_open_id = None
        self._u_test = None

    @property
    def fuza(self):
        return self._fuza

    @fuza.setter
    def fuza(self, value):
        if isinstance(value, TestDemoWzw):
            self._fuza = value
        else:
            self._fuza = TestDemoWzw.from_alipay_dict(value)
    @property
    def out_open_id(self):
        return self._out_open_id

    @out_open_id.setter
    def out_open_id(self, value):
        self._out_open_id = value
    @property
    def u_test(self):
        return self._u_test

    @u_test.setter
    def u_test(self, value):
        self._u_test = value


    def to_alipay_dict(self):
        params = dict()
        if self.fuza:
            if hasattr(self.fuza, 'to_alipay_dict'):
                params['fuza'] = self.fuza.to_alipay_dict()
            else:
                params['fuza'] = self.fuza
        if self.out_open_id:
            if hasattr(self.out_open_id, 'to_alipay_dict'):
                params['out_open_id'] = self.out_open_id.to_alipay_dict()
            else:
                params['out_open_id'] = self.out_open_id
        if self.u_test:
            if hasattr(self.u_test, 'to_alipay_dict'):
                params['u_test'] = self.u_test.to_alipay_dict()
            else:
                params['u_test'] = self.u_test
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenOperationOpenbizmockTestQueryModel()
        if 'fuza' in d:
            o.fuza = d['fuza']
        if 'out_open_id' in d:
            o.out_open_id = d['out_open_id']
        if 'u_test' in d:
            o.u_test = d['u_test']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.EquityInfo import EquityInfo


class AlipayMarketingDataEquitySyncModel(object):

    def __init__(self):
        self._biz_time = None
        self._equity_code = None
        self._equity_from = None
        self._equity_id = None
        self._equity_info = None
        self._open_id = None
        self._original_biz_no = None
        self._original_biz_type = None
        self._out_biz_no = None
        self._user_id = None

    @property
    def biz_time(self):
        return self._biz_time

    @biz_time.setter
    def biz_time(self, value):
        self._biz_time = value
    @property
    def equity_code(self):
        return self._equity_code

    @equity_code.setter
    def equity_code(self, value):
        self._equity_code = value
    @property
    def equity_from(self):
        return self._equity_from

    @equity_from.setter
    def equity_from(self, value):
        self._equity_from = value
    @property
    def equity_id(self):
        return self._equity_id

    @equity_id.setter
    def equity_id(self, value):
        self._equity_id = value
    @property
    def equity_info(self):
        return self._equity_info

    @equity_info.setter
    def equity_info(self, value):
        if isinstance(value, EquityInfo):
            self._equity_info = value
        else:
            self._equity_info = EquityInfo.from_alipay_dict(value)
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def original_biz_no(self):
        return self._original_biz_no

    @original_biz_no.setter
    def original_biz_no(self, value):
        self._original_biz_no = value
    @property
    def original_biz_type(self):
        return self._original_biz_type

    @original_biz_type.setter
    def original_biz_type(self, value):
        self._original_biz_type = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_time:
            if hasattr(self.biz_time, 'to_alipay_dict'):
                params['biz_time'] = self.biz_time.to_alipay_dict()
            else:
                params['biz_time'] = self.biz_time
        if self.equity_code:
            if hasattr(self.equity_code, 'to_alipay_dict'):
                params['equity_code'] = self.equity_code.to_alipay_dict()
            else:
                params['equity_code'] = self.equity_code
        if self.equity_from:
            if hasattr(self.equity_from, 'to_alipay_dict'):
                params['equity_from'] = self.equity_from.to_alipay_dict()
            else:
                params['equity_from'] = self.equity_from
        if self.equity_id:
            if hasattr(self.equity_id, 'to_alipay_dict'):
                params['equity_id'] = self.equity_id.to_alipay_dict()
            else:
                params['equity_id'] = self.equity_id
        if self.equity_info:
            if hasattr(self.equity_info, 'to_alipay_dict'):
                params['equity_info'] = self.equity_info.to_alipay_dict()
            else:
                params['equity_info'] = self.equity_info
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.original_biz_no:
            if hasattr(self.original_biz_no, 'to_alipay_dict'):
                params['original_biz_no'] = self.original_biz_no.to_alipay_dict()
            else:
                params['original_biz_no'] = self.original_biz_no
        if self.original_biz_type:
            if hasattr(self.original_biz_type, 'to_alipay_dict'):
                params['original_biz_type'] = self.original_biz_type.to_alipay_dict()
            else:
                params['original_biz_type'] = self.original_biz_type
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingDataEquitySyncModel()
        if 'biz_time' in d:
            o.biz_time = d['biz_time']
        if 'equity_code' in d:
            o.equity_code = d['equity_code']
        if 'equity_from' in d:
            o.equity_from = d['equity_from']
        if 'equity_id' in d:
            o.equity_id = d['equity_id']
        if 'equity_info' in d:
            o.equity_info = d['equity_info']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'original_biz_no' in d:
            o.original_biz_no = d['original_biz_no']
        if 'original_biz_type' in d:
            o.original_biz_type = d['original_biz_type']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceOperationUserPointExchangeModel(object):

    def __init__(self):
        self._benefit_id = None
        self._biz_time = None
        self._item_id = None
        self._item_name = None
        self._open_id = None
        self._point = None
        self._request_id = None
        self._scene_code = None
        self._source = None
        self._user_id = None

    @property
    def benefit_id(self):
        return self._benefit_id

    @benefit_id.setter
    def benefit_id(self, value):
        self._benefit_id = value
    @property
    def biz_time(self):
        return self._biz_time

    @biz_time.setter
    def biz_time(self, value):
        self._biz_time = value
    @property
    def item_id(self):
        return self._item_id

    @item_id.setter
    def item_id(self, value):
        self._item_id = value
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value
    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def point(self):
        return self._point

    @point.setter
    def point(self, value):
        self._point = value
    @property
    def request_id(self):
        return self._request_id

    @request_id.setter
    def request_id(self, value):
        self._request_id = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.benefit_id:
            if hasattr(self.benefit_id, 'to_alipay_dict'):
                params['benefit_id'] = self.benefit_id.to_alipay_dict()
            else:
                params['benefit_id'] = self.benefit_id
        if self.biz_time:
            if hasattr(self.biz_time, 'to_alipay_dict'):
                params['biz_time'] = self.biz_time.to_alipay_dict()
            else:
                params['biz_time'] = self.biz_time
        if self.item_id:
            if hasattr(self.item_id, 'to_alipay_dict'):
                params['item_id'] = self.item_id.to_alipay_dict()
            else:
                params['item_id'] = self.item_id
        if self.item_name:
            if hasattr(self.item_name, 'to_alipay_dict'):
                params['item_name'] = self.item_name.to_alipay_dict()
            else:
                params['item_name'] = self.item_name
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.point:
            if hasattr(self.point, 'to_alipay_dict'):
                params['point'] = self.point.to_alipay_dict()
            else:
                params['point'] = self.point
        if self.request_id:
            if hasattr(self.request_id, 'to_alipay_dict'):
                params['request_id'] = self.request_id.to_alipay_dict()
            else:
                params['request_id'] = self.request_id
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceOperationUserPointExchangeModel()
        if 'benefit_id' in d:
            o.benefit_id = d['benefit_id']
        if 'biz_time' in d:
            o.biz_time = d['biz_time']
        if 'item_id' in d:
            o.item_id = d['item_id']
        if 'item_name' in d:
            o.item_name = d['item_name']
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'point' in d:
            o.point = d['point']
        if 'request_id' in d:
            o.request_id = d['request_id']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'source' in d:
            o.source = d['source']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AntMerchantMemberwalletRechargeCreateResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantMemberwalletRechargeCreateResponse, self).__init__()
        self._order_id = None

    @property
    def order_id(self):
        return self._order_id

    @order_id.setter
    def order_id(self, value):
        self._order_id = value

    def parse_response_content(self, response_content):
        response = super(AntMerchantMemberwalletRechargeCreateResponse, self).parse_response_content(response_content)
        if 'order_id' in response:
            self.order_id = response['order_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AccessFailReasonInfo(object):

    def __init__(self):
        self._action_url = None
        self._reason_text = None

    @property
    def action_url(self):
        return self._action_url

    @action_url.setter
    def action_url(self, value):
        self._action_url = value
    @property
    def reason_text(self):
        return self._reason_text

    @reason_text.setter
    def reason_text(self, value):
        self._reason_text = value


    def to_alipay_dict(self):
        params = dict()
        if self.action_url:
            if hasattr(self.action_url, 'to_alipay_dict'):
                params['action_url'] = self.action_url.to_alipay_dict()
            else:
                params['action_url'] = self.action_url
        if self.reason_text:
            if hasattr(self.reason_text, 'to_alipay_dict'):
                params['reason_text'] = self.reason_text.to_alipay_dict()
            else:
                params['reason_text'] = self.reason_text
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AccessFailReasonInfo()
        if 'action_url' in d:
            o.action_url = d['action_url']
        if 'reason_text' in d:
            o.reason_text = d['reason_text']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ProductSimpleInfo(object):

    def __init__(self):
        self._category_name = None
        self._count = None
        self._end_time = None
        self._product_name = None
        self._product_type = None
        self._sale_price = None
        self._start_time = None
        self._zone_name = None

    @property
    def category_name(self):
        return self._category_name

    @category_name.setter
    def category_name(self, value):
        self._category_name = value
    @property
    def count(self):
        return self._count

    @count.setter
    def count(self, value):
        self._count = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def product_name(self):
        return self._product_name

    @product_name.setter
    def product_name(self, value):
        self._product_name = value
    @property
    def product_type(self):
        return self._product_type

    @product_type.setter
    def product_type(self, value):
        self._product_type = value
    @property
    def sale_price(self):
        return self._sale_price

    @sale_price.setter
    def sale_price(self, value):
        self._sale_price = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def zone_name(self):
        return self._zone_name

    @zone_name.setter
    def zone_name(self, value):
        self._zone_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.category_name:
            if hasattr(self.category_name, 'to_alipay_dict'):
                params['category_name'] = self.category_name.to_alipay_dict()
            else:
                params['category_name'] = self.category_name
        if self.count:
            if hasattr(self.count, 'to_alipay_dict'):
                params['count'] = self.count.to_alipay_dict()
            else:
                params['count'] = self.count
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.product_name:
            if hasattr(self.product_name, 'to_alipay_dict'):
                params['product_name'] = self.product_name.to_alipay_dict()
            else:
                params['product_name'] = self.product_name
        if self.product_type:
            if hasattr(self.product_type, 'to_alipay_dict'):
                params['product_type'] = self.product_type.to_alipay_dict()
            else:
                params['product_type'] = self.product_type
        if self.sale_price:
            if hasattr(self.sale_price, 'to_alipay_dict'):
                params['sale_price'] = self.sale_price.to_alipay_dict()
            else:
                params['sale_price'] = self.sale_price
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.zone_name:
            if hasattr(self.zone_name, 'to_alipay_dict'):
                params['zone_name'] = self.zone_name.to_alipay_dict()
            else:
                params['zone_name'] = self.zone_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ProductSimpleInfo()
        if 'category_name' in d:
            o.category_name = d['category_name']
        if 'count' in d:
            o.count = d['count']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'product_name' in d:
            o.product_name = d['product_name']
        if 'product_type' in d:
            o.product_type = d['product_type']
        if 'sale_price' in d:
            o.sale_price = d['sale_price']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'zone_name' in d:
            o.zone_name = d['zone_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class ZhimaCustomerAuthMutualviewApplyResponse(AlipayResponse):

    def __init__(self):
        super(ZhimaCustomerAuthMutualviewApplyResponse, self).__init__()
        self._auth_id = None
        self._cancel_result = None
        self._describe = None
        self._error_code = None
        self._error_message = None
        self._outer_sign = None

    @property
    def auth_id(self):
        return self._auth_id

    @auth_id.setter
    def auth_id(self, value):
        self._auth_id = value
    @property
    def cancel_result(self):
        return self._cancel_result

    @cancel_result.setter
    def cancel_result(self, value):
        self._cancel_result = value
    @property
    def describe(self):
        return self._describe

    @describe.setter
    def describe(self, value):
        self._describe = value
    @property
    def error_code(self):
        return self._error_code

    @error_code.setter
    def error_code(self, value):
        self._error_code = value
    @property
    def error_message(self):
        return self._error_message

    @error_message.setter
    def error_message(self, value):
        self._error_message = value
    @property
    def outer_sign(self):
        return self._outer_sign

    @outer_sign.setter
    def outer_sign(self, value):
        self._outer_sign = value

    def parse_response_content(self, response_content):
        response = super(ZhimaCustomerAuthMutualviewApplyResponse, self).parse_response_content(response_content)
        if 'auth_id' in response:
            self.auth_id = response['auth_id']
        if 'cancel_result' in response:
            self.cancel_result = response['cancel_result']
        if 'describe' in response:
            self.describe = response['describe']
        if 'error_code' in response:
            self.error_code = response['error_code']
        if 'error_message' in response:
            self.error_message = response['error_message']
        if 'outer_sign' in response:
            self.outer_sign = response['outer_sign']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.NiukeExamCallbackRequest import NiukeExamCallbackRequest


class AlipayDigitalmgmtHrcampuscoreNiukeexamResultSyncModel(object):

    def __init__(self):
        self._niuke_exam_callback_request = None

    @property
    def niuke_exam_callback_request(self):
        return self._niuke_exam_callback_request

    @niuke_exam_callback_request.setter
    def niuke_exam_callback_request(self, value):
        if isinstance(value, NiukeExamCallbackRequest):
            self._niuke_exam_callback_request = value
        else:
            self._niuke_exam_callback_request = NiukeExamCallbackRequest.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.niuke_exam_callback_request:
            if hasattr(self.niuke_exam_callback_request, 'to_alipay_dict'):
                params['niuke_exam_callback_request'] = self.niuke_exam_callback_request.to_alipay_dict()
            else:
                params['niuke_exam_callback_request'] = self.niuke_exam_callback_request
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDigitalmgmtHrcampuscoreNiukeexamResultSyncModel()
        if 'niuke_exam_callback_request' in d:
            o.niuke_exam_callback_request = d['niuke_exam_callback_request']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.AppVisitTrendDataResponse import AppVisitTrendDataResponse


class AlipayOpenMiniDataVisittrendQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenMiniDataVisittrendQueryResponse, self).__init__()
        self._app_visit_trend_data_list_response = None

    @property
    def app_visit_trend_data_list_response(self):
        return self._app_visit_trend_data_list_response

    @app_visit_trend_data_list_response.setter
    def app_visit_trend_data_list_response(self, value):
        if isinstance(value, list):
            self._app_visit_trend_data_list_response = list()
            for i in value:
                if isinstance(i, AppVisitTrendDataResponse):
                    self._app_visit_trend_data_list_response.append(i)
                else:
                    self._app_visit_trend_data_list_response.append(AppVisitTrendDataResponse.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayOpenMiniDataVisittrendQueryResponse, self).parse_response_content(response_content)
        if 'app_visit_trend_data_list_response' in response:
            self.app_visit_trend_data_list_response = response['app_visit_trend_data_list_response']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class DatadigitalFincloudFinsaasTenantchannelListBatchqueryModel(object):

    def __init__(self):
        self._channel_category = None
        self._status = None
        self._tenant_code = None

    @property
    def channel_category(self):
        return self._channel_category

    @channel_category.setter
    def channel_category(self, value):
        self._channel_category = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def tenant_code(self):
        return self._tenant_code

    @tenant_code.setter
    def tenant_code(self, value):
        self._tenant_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.channel_category:
            if hasattr(self.channel_category, 'to_alipay_dict'):
                params['channel_category'] = self.channel_category.to_alipay_dict()
            else:
                params['channel_category'] = self.channel_category
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.tenant_code:
            if hasattr(self.tenant_code, 'to_alipay_dict'):
                params['tenant_code'] = self.tenant_code.to_alipay_dict()
            else:
                params['tenant_code'] = self.tenant_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DatadigitalFincloudFinsaasTenantchannelListBatchqueryModel()
        if 'channel_category' in d:
            o.channel_category = d['channel_category']
        if 'status' in d:
            o.status = d['status']
        if 'tenant_code' in d:
            o.tenant_code = d['tenant_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AntMerchantExpandIndirectZftDeleteModel(object):

    def __init__(self):
        self._smid = None

    @property
    def smid(self):
        return self._smid

    @smid.setter
    def smid(self, value):
        self._smid = value


    def to_alipay_dict(self):
        params = dict()
        if self.smid:
            if hasattr(self.smid, 'to_alipay_dict'):
                params['smid'] = self.smid.to_alipay_dict()
            else:
                params['smid'] = self.smid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AntMerchantExpandIndirectZftDeleteModel()
        if 'smid' in d:
            o.smid = d['smid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceIotDeviceAddressQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceIotDeviceAddressQueryResponse, self).__init__()
        self._city_name = None
        self._country_name = None
        self._county_name = None
        self._province_name = None
        self._town_name = None

    @property
    def city_name(self):
        return self._city_name

    @city_name.setter
    def city_name(self, value):
        self._city_name = value
    @property
    def country_name(self):
        return self._country_name

    @country_name.setter
    def country_name(self, value):
        self._country_name = value
    @property
    def county_name(self):
        return self._county_name

    @county_name.setter
    def county_name(self, value):
        self._county_name = value
    @property
    def province_name(self):
        return self._province_name

    @province_name.setter
    def province_name(self, value):
        self._province_name = value
    @property
    def town_name(self):
        return self._town_name

    @town_name.setter
    def town_name(self, value):
        self._town_name = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceIotDeviceAddressQueryResponse, self).parse_response_content(response_content)
        if 'city_name' in response:
            self.city_name = response['city_name']
        if 'country_name' in response:
            self.country_name = response['country_name']
        if 'county_name' in response:
            self.county_name = response['county_name']
        if 'province_name' in response:
            self.province_name = response['province_name']
        if 'town_name' in response:
            self.town_name = response['town_name']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class InqueryDoctorData(object):

    def __init__(self):
        self._avator = None
        self._change_type = None
        self._department_name = None
        self._doctor_desc = None
        self._doctor_name = None
        self._gender = None
        self._hospital_name = None
        self._id_no = None
        self._practice_year = None
        self._practicing_doctor_certificate_no = None
        self._skilled_desc = None
        self._skilled_disease = None
        self._special_tags = None
        self._title = None

    @property
    def avator(self):
        return self._avator

    @avator.setter
    def avator(self, value):
        self._avator = value
    @property
    def change_type(self):
        return self._change_type

    @change_type.setter
    def change_type(self, value):
        self._change_type = value
    @property
    def department_name(self):
        return self._department_name

    @department_name.setter
    def department_name(self, value):
        self._department_name = value
    @property
    def doctor_desc(self):
        return self._doctor_desc

    @doctor_desc.setter
    def doctor_desc(self, value):
        self._doctor_desc = value
    @property
    def doctor_name(self):
        return self._doctor_name

    @doctor_name.setter
    def doctor_name(self, value):
        self._doctor_name = value
    @property
    def gender(self):
        return self._gender

    @gender.setter
    def gender(self, value):
        self._gender = value
    @property
    def hospital_name(self):
        return self._hospital_name

    @hospital_name.setter
    def hospital_name(self, value):
        self._hospital_name = value
    @property
    def id_no(self):
        return self._id_no

    @id_no.setter
    def id_no(self, value):
        self._id_no = value
    @property
    def practice_year(self):
        return self._practice_year

    @practice_year.setter
    def practice_year(self, value):
        self._practice_year = value
    @property
    def practicing_doctor_certificate_no(self):
        return self._practicing_doctor_certificate_no

    @practicing_doctor_certificate_no.setter
    def practicing_doctor_certificate_no(self, value):
        self._practicing_doctor_certificate_no = value
    @property
    def skilled_desc(self):
        return self._skilled_desc

    @skilled_desc.setter
    def skilled_desc(self, value):
        self._skilled_desc = value
    @property
    def skilled_disease(self):
        return self._skilled_disease

    @skilled_disease.setter
    def skilled_disease(self, value):
        self._skilled_disease = value
    @property
    def special_tags(self):
        return self._special_tags

    @special_tags.setter
    def special_tags(self, value):
        self._special_tags = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value


    def to_alipay_dict(self):
        params = dict()
        if self.avator:
            if hasattr(self.avator, 'to_alipay_dict'):
                params['avator'] = self.avator.to_alipay_dict()
            else:
                params['avator'] = self.avator
        if self.change_type:
            if hasattr(self.change_type, 'to_alipay_dict'):
                params['change_type'] = self.change_type.to_alipay_dict()
            else:
                params['change_type'] = self.change_type
        if self.department_name:
            if hasattr(self.department_name, 'to_alipay_dict'):
                params['department_name'] = self.department_name.to_alipay_dict()
            else:
                params['department_name'] = self.department_name
        if self.doctor_desc:
            if hasattr(self.doctor_desc, 'to_alipay_dict'):
                params['doctor_desc'] = self.doctor_desc.to_alipay_dict()
            else:
                params['doctor_desc'] = self.doctor_desc
        if self.doctor_name:
            if hasattr(self.doctor_name, 'to_alipay_dict'):
                params['doctor_name'] = self.doctor_name.to_alipay_dict()
            else:
                params['doctor_name'] = self.doctor_name
        if self.gender:
            if hasattr(self.gender, 'to_alipay_dict'):
                params['gender'] = self.gender.to_alipay_dict()
            else:
                params['gender'] = self.gender
        if self.hospital_name:
            if hasattr(self.hospital_name, 'to_alipay_dict'):
                params['hospital_name'] = self.hospital_name.to_alipay_dict()
            else:
                params['hospital_name'] = self.hospital_name
        if self.id_no:
            if hasattr(self.id_no, 'to_alipay_dict'):
                params['id_no'] = self.id_no.to_alipay_dict()
            else:
                params['id_no'] = self.id_no
        if self.practice_year:
            if hasattr(self.practice_year, 'to_alipay_dict'):
                params['practice_year'] = self.practice_year.to_alipay_dict()
            else:
                params['practice_year'] = self.practice_year
        if self.practicing_doctor_certificate_no:
            if hasattr(self.practicing_doctor_certificate_no, 'to_alipay_dict'):
                params['practicing_doctor_certificate_no'] = self.practicing_doctor_certificate_no.to_alipay_dict()
            else:
                params['practicing_doctor_certificate_no'] = self.practicing_doctor_certificate_no
        if self.skilled_desc:
            if hasattr(self.skilled_desc, 'to_alipay_dict'):
                params['skilled_desc'] = self.skilled_desc.to_alipay_dict()
            else:
                params['skilled_desc'] = self.skilled_desc
        if self.skilled_disease:
            if hasattr(self.skilled_disease, 'to_alipay_dict'):
                params['skilled_disease'] = self.skilled_disease.to_alipay_dict()
            else:
                params['skilled_disease'] = self.skilled_disease
        if self.special_tags:
            if hasattr(self.special_tags, 'to_alipay_dict'):
                params['special_tags'] = self.special_tags.to_alipay_dict()
            else:
                params['special_tags'] = self.special_tags
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = InqueryDoctorData()
        if 'avator' in d:
            o.avator = d['avator']
        if 'change_type' in d:
            o.change_type = d['change_type']
        if 'department_name' in d:
            o.department_name = d['department_name']
        if 'doctor_desc' in d:
            o.doctor_desc = d['doctor_desc']
        if 'doctor_name' in d:
            o.doctor_name = d['doctor_name']
        if 'gender' in d:
            o.gender = d['gender']
        if 'hospital_name' in d:
            o.hospital_name = d['hospital_name']
        if 'id_no' in d:
            o.id_no = d['id_no']
        if 'practice_year' in d:
            o.practice_year = d['practice_year']
        if 'practicing_doctor_certificate_no' in d:
            o.practicing_doctor_certificate_no = d['practicing_doctor_certificate_no']
        if 'skilled_desc' in d:
            o.skilled_desc = d['skilled_desc']
        if 'skilled_disease' in d:
            o.skilled_disease = d['skilled_disease']
        if 'special_tags' in d:
            o.special_tags = d['special_tags']
        if 'title' in d:
            o.title = d['title']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ArrangementBaseVO import ArrangementBaseVO


class ArrangementVORes(object):

    def __init__(self):
        self._ar_base = None
        self._ar_bsn_status = None
        self._ar_condition = None
        self._arrangement_no = None

    @property
    def ar_base(self):
        return self._ar_base

    @ar_base.setter
    def ar_base(self, value):
        if isinstance(value, ArrangementBaseVO):
            self._ar_base = value
        else:
            self._ar_base = ArrangementBaseVO.from_alipay_dict(value)
    @property
    def ar_bsn_status(self):
        return self._ar_bsn_status

    @ar_bsn_status.setter
    def ar_bsn_status(self, value):
        self._ar_bsn_status = value
    @property
    def ar_condition(self):
        return self._ar_condition

    @ar_condition.setter
    def ar_condition(self, value):
        self._ar_condition = value
    @property
    def arrangement_no(self):
        return self._arrangement_no

    @arrangement_no.setter
    def arrangement_no(self, value):
        self._arrangement_no = value


    def to_alipay_dict(self):
        params = dict()
        if self.ar_base:
            if hasattr(self.ar_base, 'to_alipay_dict'):
                params['ar_base'] = self.ar_base.to_alipay_dict()
            else:
                params['ar_base'] = self.ar_base
        if self.ar_bsn_status:
            if hasattr(self.ar_bsn_status, 'to_alipay_dict'):
                params['ar_bsn_status'] = self.ar_bsn_status.to_alipay_dict()
            else:
                params['ar_bsn_status'] = self.ar_bsn_status
        if self.ar_condition:
            if hasattr(self.ar_condition, 'to_alipay_dict'):
                params['ar_condition'] = self.ar_condition.to_alipay_dict()
            else:
                params['ar_condition'] = self.ar_condition
        if self.arrangement_no:
            if hasattr(self.arrangement_no, 'to_alipay_dict'):
                params['arrangement_no'] = self.arrangement_no.to_alipay_dict()
            else:
                params['arrangement_no'] = self.arrangement_no
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ArrangementVORes()
        if 'ar_base' in d:
            o.ar_base = d['ar_base']
        if 'ar_bsn_status' in d:
            o.ar_bsn_status = d['ar_bsn_status']
        if 'ar_condition' in d:
            o.ar_condition = d['ar_condition']
        if 'arrangement_no' in d:
            o.arrangement_no = d['arrangement_no']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class OppositeSubjectDTO(object):

    def __init__(self):
        self._memo = None
        self._opposite_contact_addr = None
        self._opposite_contact_email = None
        self._opposite_contact_name = None
        self._opposite_contact_phone = None
        self._opposite_subject_name = None
        self._opposite_uscc = None

    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def opposite_contact_addr(self):
        return self._opposite_contact_addr

    @opposite_contact_addr.setter
    def opposite_contact_addr(self, value):
        self._opposite_contact_addr = value
    @property
    def opposite_contact_email(self):
        return self._opposite_contact_email

    @opposite_contact_email.setter
    def opposite_contact_email(self, value):
        self._opposite_contact_email = value
    @property
    def opposite_contact_name(self):
        return self._opposite_contact_name

    @opposite_contact_name.setter
    def opposite_contact_name(self, value):
        self._opposite_contact_name = value
    @property
    def opposite_contact_phone(self):
        return self._opposite_contact_phone

    @opposite_contact_phone.setter
    def opposite_contact_phone(self, value):
        self._opposite_contact_phone = value
    @property
    def opposite_subject_name(self):
        return self._opposite_subject_name

    @opposite_subject_name.setter
    def opposite_subject_name(self, value):
        self._opposite_subject_name = value
    @property
    def opposite_uscc(self):
        return self._opposite_uscc

    @opposite_uscc.setter
    def opposite_uscc(self, value):
        self._opposite_uscc = value


    def to_alipay_dict(self):
        params = dict()
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.opposite_contact_addr:
            if hasattr(self.opposite_contact_addr, 'to_alipay_dict'):
                params['opposite_contact_addr'] = self.opposite_contact_addr.to_alipay_dict()
            else:
                params['opposite_contact_addr'] = self.opposite_contact_addr
        if self.opposite_contact_email:
            if hasattr(self.opposite_contact_email, 'to_alipay_dict'):
                params['opposite_contact_email'] = self.opposite_contact_email.to_alipay_dict()
            else:
                params['opposite_contact_email'] = self.opposite_contact_email
        if self.opposite_contact_name:
            if hasattr(self.opposite_contact_name, 'to_alipay_dict'):
                params['opposite_contact_name'] = self.opposite_contact_name.to_alipay_dict()
            else:
                params['opposite_contact_name'] = self.opposite_contact_name
        if self.opposite_contact_phone:
            if hasattr(self.opposite_contact_phone, 'to_alipay_dict'):
                params['opposite_contact_phone'] = self.opposite_contact_phone.to_alipay_dict()
            else:
                params['opposite_contact_phone'] = self.opposite_contact_phone
        if self.opposite_subject_name:
            if hasattr(self.opposite_subject_name, 'to_alipay_dict'):
                params['opposite_subject_name'] = self.opposite_subject_name.to_alipay_dict()
            else:
                params['opposite_subject_name'] = self.opposite_subject_name
        if self.opposite_uscc:
            if hasattr(self.opposite_uscc, 'to_alipay_dict'):
                params['opposite_uscc'] = self.opposite_uscc.to_alipay_dict()
            else:
                params['opposite_uscc'] = self.opposite_uscc
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = OppositeSubjectDTO()
        if 'memo' in d:
            o.memo = d['memo']
        if 'opposite_contact_addr' in d:
            o.opposite_contact_addr = d['opposite_contact_addr']
        if 'opposite_contact_email' in d:
            o.opposite_contact_email = d['opposite_contact_email']
        if 'opposite_contact_name' in d:
            o.opposite_contact_name = d['opposite_contact_name']
        if 'opposite_contact_phone' in d:
            o.opposite_contact_phone = d['opposite_contact_phone']
        if 'opposite_subject_name' in d:
            o.opposite_subject_name = d['opposite_subject_name']
        if 'opposite_uscc' in d:
            o.opposite_uscc = d['opposite_uscc']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MerchantInformation(object):

    def __init__(self):
        self._address = None
        self._advance_amount = None
        self._city_desc = None
        self._collection_settlement = None
        self._country_desc = None
        self._district_desc = None
        self._mcc_code = None
        self._mcc_industry_one = None
        self._mcc_industry_two = None
        self._merchant_name = None
        self._mid = None
        self._zip_code = None

    @property
    def address(self):
        return self._address

    @address.setter
    def address(self, value):
        self._address = value
    @property
    def advance_amount(self):
        return self._advance_amount

    @advance_amount.setter
    def advance_amount(self, value):
        self._advance_amount = value
    @property
    def city_desc(self):
        return self._city_desc

    @city_desc.setter
    def city_desc(self, value):
        self._city_desc = value
    @property
    def collection_settlement(self):
        return self._collection_settlement

    @collection_settlement.setter
    def collection_settlement(self, value):
        self._collection_settlement = value
    @property
    def country_desc(self):
        return self._country_desc

    @country_desc.setter
    def country_desc(self, value):
        self._country_desc = value
    @property
    def district_desc(self):
        return self._district_desc

    @district_desc.setter
    def district_desc(self, value):
        self._district_desc = value
    @property
    def mcc_code(self):
        return self._mcc_code

    @mcc_code.setter
    def mcc_code(self, value):
        self._mcc_code = value
    @property
    def mcc_industry_one(self):
        return self._mcc_industry_one

    @mcc_industry_one.setter
    def mcc_industry_one(self, value):
        self._mcc_industry_one = value
    @property
    def mcc_industry_two(self):
        return self._mcc_industry_two

    @mcc_industry_two.setter
    def mcc_industry_two(self, value):
        self._mcc_industry_two = value
    @property
    def merchant_name(self):
        return self._merchant_name

    @merchant_name.setter
    def merchant_name(self, value):
        self._merchant_name = value
    @property
    def mid(self):
        return self._mid

    @mid.setter
    def mid(self, value):
        self._mid = value
    @property
    def zip_code(self):
        return self._zip_code

    @zip_code.setter
    def zip_code(self, value):
        self._zip_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.address:
            if hasattr(self.address, 'to_alipay_dict'):
                params['address'] = self.address.to_alipay_dict()
            else:
                params['address'] = self.address
        if self.advance_amount:
            if hasattr(self.advance_amount, 'to_alipay_dict'):
                params['advance_amount'] = self.advance_amount.to_alipay_dict()
            else:
                params['advance_amount'] = self.advance_amount
        if self.city_desc:
            if hasattr(self.city_desc, 'to_alipay_dict'):
                params['city_desc'] = self.city_desc.to_alipay_dict()
            else:
                params['city_desc'] = self.city_desc
        if self.collection_settlement:
            if hasattr(self.collection_settlement, 'to_alipay_dict'):
                params['collection_settlement'] = self.collection_settlement.to_alipay_dict()
            else:
                params['collection_settlement'] = self.collection_settlement
        if self.country_desc:
            if hasattr(self.country_desc, 'to_alipay_dict'):
                params['country_desc'] = self.country_desc.to_alipay_dict()
            else:
                params['country_desc'] = self.country_desc
        if self.district_desc:
            if hasattr(self.district_desc, 'to_alipay_dict'):
                params['district_desc'] = self.district_desc.to_alipay_dict()
            else:
                params['district_desc'] = self.district_desc
        if self.mcc_code:
            if hasattr(self.mcc_code, 'to_alipay_dict'):
                params['mcc_code'] = self.mcc_code.to_alipay_dict()
            else:
                params['mcc_code'] = self.mcc_code
        if self.mcc_industry_one:
            if hasattr(self.mcc_industry_one, 'to_alipay_dict'):
                params['mcc_industry_one'] = self.mcc_industry_one.to_alipay_dict()
            else:
                params['mcc_industry_one'] = self.mcc_industry_one
        if self.mcc_industry_two:
            if hasattr(self.mcc_industry_two, 'to_alipay_dict'):
                params['mcc_industry_two'] = self.mcc_industry_two.to_alipay_dict()
            else:
                params['mcc_industry_two'] = self.mcc_industry_two
        if self.merchant_name:
            if hasattr(self.merchant_name, 'to_alipay_dict'):
                params['merchant_name'] = self.merchant_name.to_alipay_dict()
            else:
                params['merchant_name'] = self.merchant_name
        if self.mid:
            if hasattr(self.mid, 'to_alipay_dict'):
                params['mid'] = self.mid.to_alipay_dict()
            else:
                params['mid'] = self.mid
        if self.zip_code:
            if hasattr(self.zip_code, 'to_alipay_dict'):
                params['zip_code'] = self.zip_code.to_alipay_dict()
            else:
                params['zip_code'] = self.zip_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MerchantInformation()
        if 'address' in d:
            o.address = d['address']
        if 'advance_amount' in d:
            o.advance_amount = d['advance_amount']
        if 'city_desc' in d:
            o.city_desc = d['city_desc']
        if 'collection_settlement' in d:
            o.collection_settlement = d['collection_settlement']
        if 'country_desc' in d:
            o.country_desc = d['country_desc']
        if 'district_desc' in d:
            o.district_desc = d['district_desc']
        if 'mcc_code' in d:
            o.mcc_code = d['mcc_code']
        if 'mcc_industry_one' in d:
            o.mcc_industry_one = d['mcc_industry_one']
        if 'mcc_industry_two' in d:
            o.mcc_industry_two = d['mcc_industry_two']
        if 'merchant_name' in d:
            o.merchant_name = d['merchant_name']
        if 'mid' in d:
            o.mid = d['mid']
        if 'zip_code' in d:
            o.zip_code = d['zip_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceIotDapplyDevicetradestatlistQueryModel(object):

    def __init__(self):
        self._offset = None
        self._page_size = None
        self._stat_end = None
        self._stat_start = None

    @property
    def offset(self):
        return self._offset

    @offset.setter
    def offset(self, value):
        self._offset = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def stat_end(self):
        return self._stat_end

    @stat_end.setter
    def stat_end(self, value):
        self._stat_end = value
    @property
    def stat_start(self):
        return self._stat_start

    @stat_start.setter
    def stat_start(self, value):
        self._stat_start = value


    def to_alipay_dict(self):
        params = dict()
        if self.offset:
            if hasattr(self.offset, 'to_alipay_dict'):
                params['offset'] = self.offset.to_alipay_dict()
            else:
                params['offset'] = self.offset
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.stat_end:
            if hasattr(self.stat_end, 'to_alipay_dict'):
                params['stat_end'] = self.stat_end.to_alipay_dict()
            else:
                params['stat_end'] = self.stat_end
        if self.stat_start:
            if hasattr(self.stat_start, 'to_alipay_dict'):
                params['stat_start'] = self.stat_start.to_alipay_dict()
            else:
                params['stat_start'] = self.stat_start
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceIotDapplyDevicetradestatlistQueryModel()
        if 'offset' in d:
            o.offset = d['offset']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'stat_end' in d:
            o.stat_end = d['stat_end']
        if 'stat_start' in d:
            o.stat_start = d['stat_start']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class EduPlanInstanceInfo(object):

    def __init__(self):
        self._plan_instance_no = None
        self._plan_status = None
        self._serial = None

    @property
    def plan_instance_no(self):
        return self._plan_instance_no

    @plan_instance_no.setter
    def plan_instance_no(self, value):
        self._plan_instance_no = value
    @property
    def plan_status(self):
        return self._plan_status

    @plan_status.setter
    def plan_status(self, value):
        self._plan_status = value
    @property
    def serial(self):
        return self._serial

    @serial.setter
    def serial(self, value):
        self._serial = value


    def to_alipay_dict(self):
        params = dict()
        if self.plan_instance_no:
            if hasattr(self.plan_instance_no, 'to_alipay_dict'):
                params['plan_instance_no'] = self.plan_instance_no.to_alipay_dict()
            else:
                params['plan_instance_no'] = self.plan_instance_no
        if self.plan_status:
            if hasattr(self.plan_status, 'to_alipay_dict'):
                params['plan_status'] = self.plan_status.to_alipay_dict()
            else:
                params['plan_status'] = self.plan_status
        if self.serial:
            if hasattr(self.serial, 'to_alipay_dict'):
                params['serial'] = self.serial.to_alipay_dict()
            else:
                params['serial'] = self.serial
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = EduPlanInstanceInfo()
        if 'plan_instance_no' in d:
            o.plan_instance_no = d['plan_instance_no']
        if 'plan_status' in d:
            o.plan_status = d['plan_status']
        if 'serial' in d:
            o.serial = d['serial']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.BizData import BizData


class AlipayOpenAppCommunityDataSyncModel(object):

    def __init__(self):
        self._action = None
        self._batch_no = None
        self._biz_type = None
        self._data_list = None
        self._type = None

    @property
    def action(self):
        return self._action

    @action.setter
    def action(self, value):
        self._action = value
    @property
    def batch_no(self):
        return self._batch_no

    @batch_no.setter
    def batch_no(self, value):
        self._batch_no = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def data_list(self):
        return self._data_list

    @data_list.setter
    def data_list(self, value):
        if isinstance(value, list):
            self._data_list = list()
            for i in value:
                if isinstance(i, BizData):
                    self._data_list.append(i)
                else:
                    self._data_list.append(BizData.from_alipay_dict(i))
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.action:
            if hasattr(self.action, 'to_alipay_dict'):
                params['action'] = self.action.to_alipay_dict()
            else:
                params['action'] = self.action
        if self.batch_no:
            if hasattr(self.batch_no, 'to_alipay_dict'):
                params['batch_no'] = self.batch_no.to_alipay_dict()
            else:
                params['batch_no'] = self.batch_no
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.data_list:
            if isinstance(self.data_list, list):
                for i in range(0, len(self.data_list)):
                    element = self.data_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.data_list[i] = element.to_alipay_dict()
            if hasattr(self.data_list, 'to_alipay_dict'):
                params['data_list'] = self.data_list.to_alipay_dict()
            else:
                params['data_list'] = self.data_list
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppCommunityDataSyncModel()
        if 'action' in d:
            o.action = d['action']
        if 'batch_no' in d:
            o.batch_no = d['batch_no']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'data_list' in d:
            o.data_list = d['data_list']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CloudbusLocation import CloudbusLocation
from alipay.aop.api.domain.CloudbusStop import CloudbusStop


class CloudbusPredictRItem(object):

    def __init__(self):
        self._line_lon_lat = None
        self._operation_time = None
        self._route_volume = None
        self._stops = None

    @property
    def line_lon_lat(self):
        return self._line_lon_lat

    @line_lon_lat.setter
    def line_lon_lat(self, value):
        if isinstance(value, list):
            self._line_lon_lat = list()
            for i in value:
                if isinstance(i, CloudbusLocation):
                    self._line_lon_lat.append(i)
                else:
                    self._line_lon_lat.append(CloudbusLocation.from_alipay_dict(i))
    @property
    def operation_time(self):
        return self._operation_time

    @operation_time.setter
    def operation_time(self, value):
        if isinstance(value, list):
            self._operation_time = list()
            for i in value:
                self._operation_time.append(i)
    @property
    def route_volume(self):
        return self._route_volume

    @route_volume.setter
    def route_volume(self, value):
        self._route_volume = value
    @property
    def stops(self):
        return self._stops

    @stops.setter
    def stops(self, value):
        if isinstance(value, list):
            self._stops = list()
            for i in value:
                if isinstance(i, CloudbusStop):
                    self._stops.append(i)
                else:
                    self._stops.append(CloudbusStop.from_alipay_dict(i))


    def to_alipay_dict(self):
        params = dict()
        if self.line_lon_lat:
            if isinstance(self.line_lon_lat, list):
                for i in range(0, len(self.line_lon_lat)):
                    element = self.line_lon_lat[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.line_lon_lat[i] = element.to_alipay_dict()
            if hasattr(self.line_lon_lat, 'to_alipay_dict'):
                params['line_lon_lat'] = self.line_lon_lat.to_alipay_dict()
            else:
                params['line_lon_lat'] = self.line_lon_lat
        if self.operation_time:
            if isinstance(self.operation_time, list):
                for i in range(0, len(self.operation_time)):
                    element = self.operation_time[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.operation_time[i] = element.to_alipay_dict()
            if hasattr(self.operation_time, 'to_alipay_dict'):
                params['operation_time'] = self.operation_time.to_alipay_dict()
            else:
                params['operation_time'] = self.operation_time
        if self.route_volume:
            if hasattr(self.route_volume, 'to_alipay_dict'):
                params['route_volume'] = self.route_volume.to_alipay_dict()
            else:
                params['route_volume'] = self.route_volume
        if self.stops:
            if isinstance(self.stops, list):
                for i in range(0, len(self.stops)):
                    element = self.stops[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.stops[i] = element.to_alipay_dict()
            if hasattr(self.stops, 'to_alipay_dict'):
                params['stops'] = self.stops.to_alipay_dict()
            else:
                params['stops'] = self.stops
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CloudbusPredictRItem()
        if 'line_lon_lat' in d:
            o.line_lon_lat = d['line_lon_lat']
        if 'operation_time' in d:
            o.operation_time = d['operation_time']
        if 'route_volume' in d:
            o.route_volume = d['route_volume']
        if 'stops' in d:
            o.stops = d['stops']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SupplierReportDetail(object):

    def __init__(self):
        self._batch_code = None
        self._expire_date = None
        self._goods_code = None
        self._inventory_type = None
        self._price = None
        self._production_date = None
        self._quantity_diff = None
        self._report_type = None
        self._supplier_report_detail_id = None
        self._supplier_report_id = None

    @property
    def batch_code(self):
        return self._batch_code

    @batch_code.setter
    def batch_code(self, value):
        self._batch_code = value
    @property
    def expire_date(self):
        return self._expire_date

    @expire_date.setter
    def expire_date(self, value):
        self._expire_date = value
    @property
    def goods_code(self):
        return self._goods_code

    @goods_code.setter
    def goods_code(self, value):
        self._goods_code = value
    @property
    def inventory_type(self):
        return self._inventory_type

    @inventory_type.setter
    def inventory_type(self, value):
        self._inventory_type = value
    @property
    def price(self):
        return self._price

    @price.setter
    def price(self, value):
        self._price = value
    @property
    def production_date(self):
        return self._production_date

    @production_date.setter
    def production_date(self, value):
        self._production_date = value
    @property
    def quantity_diff(self):
        return self._quantity_diff

    @quantity_diff.setter
    def quantity_diff(self, value):
        self._quantity_diff = value
    @property
    def report_type(self):
        return self._report_type

    @report_type.setter
    def report_type(self, value):
        self._report_type = value
    @property
    def supplier_report_detail_id(self):
        return self._supplier_report_detail_id

    @supplier_report_detail_id.setter
    def supplier_report_detail_id(self, value):
        self._supplier_report_detail_id = value
    @property
    def supplier_report_id(self):
        return self._supplier_report_id

    @supplier_report_id.setter
    def supplier_report_id(self, value):
        self._supplier_report_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.batch_code:
            if hasattr(self.batch_code, 'to_alipay_dict'):
                params['batch_code'] = self.batch_code.to_alipay_dict()
            else:
                params['batch_code'] = self.batch_code
        if self.expire_date:
            if hasattr(self.expire_date, 'to_alipay_dict'):
                params['expire_date'] = self.expire_date.to_alipay_dict()
            else:
                params['expire_date'] = self.expire_date
        if self.goods_code:
            if hasattr(self.goods_code, 'to_alipay_dict'):
                params['goods_code'] = self.goods_code.to_alipay_dict()
            else:
                params['goods_code'] = self.goods_code
        if self.inventory_type:
            if hasattr(self.inventory_type, 'to_alipay_dict'):
                params['inventory_type'] = self.inventory_type.to_alipay_dict()
            else:
                params['inventory_type'] = self.inventory_type
        if self.price:
            if hasattr(self.price, 'to_alipay_dict'):
                params['price'] = self.price.to_alipay_dict()
            else:
                params['price'] = self.price
        if self.production_date:
            if hasattr(self.production_date, 'to_alipay_dict'):
                params['production_date'] = self.production_date.to_alipay_dict()
            else:
                params['production_date'] = self.production_date
        if self.quantity_diff:
            if hasattr(self.quantity_diff, 'to_alipay_dict'):
                params['quantity_diff'] = self.quantity_diff.to_alipay_dict()
            else:
                params['quantity_diff'] = self.quantity_diff
        if self.report_type:
            if hasattr(self.report_type, 'to_alipay_dict'):
                params['report_type'] = self.report_type.to_alipay_dict()
            else:
                params['report_type'] = self.report_type
        if self.supplier_report_detail_id:
            if hasattr(self.supplier_report_detail_id, 'to_alipay_dict'):
                params['supplier_report_detail_id'] = self.supplier_report_detail_id.to_alipay_dict()
            else:
                params['supplier_report_detail_id'] = self.supplier_report_detail_id
        if self.supplier_report_id:
            if hasattr(self.supplier_report_id, 'to_alipay_dict'):
                params['supplier_report_id'] = self.supplier_report_id.to_alipay_dict()
            else:
                params['supplier_report_id'] = self.supplier_report_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SupplierReportDetail()
        if 'batch_code' in d:
            o.batch_code = d['batch_code']
        if 'expire_date' in d:
            o.expire_date = d['expire_date']
        if 'goods_code' in d:
            o.goods_code = d['goods_code']
        if 'inventory_type' in d:
            o.inventory_type = d['inventory_type']
        if 'price' in d:
            o.price = d['price']
        if 'production_date' in d:
            o.production_date = d['production_date']
        if 'quantity_diff' in d:
            o.quantity_diff = d['quantity_diff']
        if 'report_type' in d:
            o.report_type = d['report_type']
        if 'supplier_report_detail_id' in d:
            o.supplier_report_detail_id = d['supplier_report_detail_id']
        if 'supplier_report_id' in d:
            o.supplier_report_id = d['supplier_report_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayBossProdAntsignUserCreateModel(object):

    def __init__(self):
        self._app_name = None
        self._business_line_code = None
        self._cert_number = None
        self._scene_code = None
        self._tenant = None
        self._user_cert_type = None
        self._user_name = None
        self._user_type = None

    @property
    def app_name(self):
        return self._app_name

    @app_name.setter
    def app_name(self, value):
        self._app_name = value
    @property
    def business_line_code(self):
        return self._business_line_code

    @business_line_code.setter
    def business_line_code(self, value):
        self._business_line_code = value
    @property
    def cert_number(self):
        return self._cert_number

    @cert_number.setter
    def cert_number(self, value):
        self._cert_number = value
    @property
    def scene_code(self):
        return self._scene_code

    @scene_code.setter
    def scene_code(self, value):
        self._scene_code = value
    @property
    def tenant(self):
        return self._tenant

    @tenant.setter
    def tenant(self, value):
        self._tenant = value
    @property
    def user_cert_type(self):
        return self._user_cert_type

    @user_cert_type.setter
    def user_cert_type(self, value):
        self._user_cert_type = value
    @property
    def user_name(self):
        return self._user_name

    @user_name.setter
    def user_name(self, value):
        self._user_name = value
    @property
    def user_type(self):
        return self._user_type

    @user_type.setter
    def user_type(self, value):
        self._user_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_name:
            if hasattr(self.app_name, 'to_alipay_dict'):
                params['app_name'] = self.app_name.to_alipay_dict()
            else:
                params['app_name'] = self.app_name
        if self.business_line_code:
            if hasattr(self.business_line_code, 'to_alipay_dict'):
                params['business_line_code'] = self.business_line_code.to_alipay_dict()
            else:
                params['business_line_code'] = self.business_line_code
        if self.cert_number:
            if hasattr(self.cert_number, 'to_alipay_dict'):
                params['cert_number'] = self.cert_number.to_alipay_dict()
            else:
                params['cert_number'] = self.cert_number
        if self.scene_code:
            if hasattr(self.scene_code, 'to_alipay_dict'):
                params['scene_code'] = self.scene_code.to_alipay_dict()
            else:
                params['scene_code'] = self.scene_code
        if self.tenant:
            if hasattr(self.tenant, 'to_alipay_dict'):
                params['tenant'] = self.tenant.to_alipay_dict()
            else:
                params['tenant'] = self.tenant
        if self.user_cert_type:
            if hasattr(self.user_cert_type, 'to_alipay_dict'):
                params['user_cert_type'] = self.user_cert_type.to_alipay_dict()
            else:
                params['user_cert_type'] = self.user_cert_type
        if self.user_name:
            if hasattr(self.user_name, 'to_alipay_dict'):
                params['user_name'] = self.user_name.to_alipay_dict()
            else:
                params['user_name'] = self.user_name
        if self.user_type:
            if hasattr(self.user_type, 'to_alipay_dict'):
                params['user_type'] = self.user_type.to_alipay_dict()
            else:
                params['user_type'] = self.user_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayBossProdAntsignUserCreateModel()
        if 'app_name' in d:
            o.app_name = d['app_name']
        if 'business_line_code' in d:
            o.business_line_code = d['business_line_code']
        if 'cert_number' in d:
            o.cert_number = d['cert_number']
        if 'scene_code' in d:
            o.scene_code = d['scene_code']
        if 'tenant' in d:
            o.tenant = d['tenant']
        if 'user_cert_type' in d:
            o.user_cert_type = d['user_cert_type']
        if 'user_name' in d:
            o.user_name = d['user_name']
        if 'user_type' in d:
            o.user_type = d['user_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.HeatMapData import HeatMapData


class AlipayCommerceTransportTaxiHeatmapQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceTransportTaxiHeatmapQueryResponse, self).__init__()
        self._heatmap_data = None

    @property
    def heatmap_data(self):
        return self._heatmap_data

    @heatmap_data.setter
    def heatmap_data(self, value):
        if isinstance(value, HeatMapData):
            self._heatmap_data = value
        else:
            self._heatmap_data = HeatMapData.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceTransportTaxiHeatmapQueryResponse, self).parse_response_content(response_content)
        if 'heatmap_data' in response:
            self.heatmap_data = response['heatmap_data']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class LargeInfiniteCardInfo(object):

    def __init__(self):
        self._account_balance = None
        self._bank_account_name = None
        self._bank_account_no = None
        self._bank_branch = None
        self._bank_branch_code = None
        self._bank_name = None
        self._open_place = None

    @property
    def account_balance(self):
        return self._account_balance

    @account_balance.setter
    def account_balance(self, value):
        self._account_balance = value
    @property
    def bank_account_name(self):
        return self._bank_account_name

    @bank_account_name.setter
    def bank_account_name(self, value):
        self._bank_account_name = value
    @property
    def bank_account_no(self):
        return self._bank_account_no

    @bank_account_no.setter
    def bank_account_no(self, value):
        self._bank_account_no = value
    @property
    def bank_branch(self):
        return self._bank_branch

    @bank_branch.setter
    def bank_branch(self, value):
        self._bank_branch = value
    @property
    def bank_branch_code(self):
        return self._bank_branch_code

    @bank_branch_code.setter
    def bank_branch_code(self, value):
        self._bank_branch_code = value
    @property
    def bank_name(self):
        return self._bank_name

    @bank_name.setter
    def bank_name(self, value):
        self._bank_name = value
    @property
    def open_place(self):
        return self._open_place

    @open_place.setter
    def open_place(self, value):
        self._open_place = value


    def to_alipay_dict(self):
        params = dict()
        if self.account_balance:
            if hasattr(self.account_balance, 'to_alipay_dict'):
                params['account_balance'] = self.account_balance.to_alipay_dict()
            else:
                params['account_balance'] = self.account_balance
        if self.bank_account_name:
            if hasattr(self.bank_account_name, 'to_alipay_dict'):
                params['bank_account_name'] = self.bank_account_name.to_alipay_dict()
            else:
                params['bank_account_name'] = self.bank_account_name
        if self.bank_account_no:
            if hasattr(self.bank_account_no, 'to_alipay_dict'):
                params['bank_account_no'] = self.bank_account_no.to_alipay_dict()
            else:
                params['bank_account_no'] = self.bank_account_no
        if self.bank_branch:
            if hasattr(self.bank_branch, 'to_alipay_dict'):
                params['bank_branch'] = self.bank_branch.to_alipay_dict()
            else:
                params['bank_branch'] = self.bank_branch
        if self.bank_branch_code:
            if hasattr(self.bank_branch_code, 'to_alipay_dict'):
                params['bank_branch_code'] = self.bank_branch_code.to_alipay_dict()
            else:
                params['bank_branch_code'] = self.bank_branch_code
        if self.bank_name:
            if hasattr(self.bank_name, 'to_alipay_dict'):
                params['bank_name'] = self.bank_name.to_alipay_dict()
            else:
                params['bank_name'] = self.bank_name
        if self.open_place:
            if hasattr(self.open_place, 'to_alipay_dict'):
                params['open_place'] = self.open_place.to_alipay_dict()
            else:
                params['open_place'] = self.open_place
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = LargeInfiniteCardInfo()
        if 'account_balance' in d:
            o.account_balance = d['account_balance']
        if 'bank_account_name' in d:
            o.bank_account_name = d['bank_account_name']
        if 'bank_account_no' in d:
            o.bank_account_no = d['bank_account_no']
        if 'bank_branch' in d:
            o.bank_branch = d['bank_branch']
        if 'bank_branch_code' in d:
            o.bank_branch_code = d['bank_branch_code']
        if 'bank_name' in d:
            o.bank_name = d['bank_name']
        if 'open_place' in d:
            o.open_place = d['open_place']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniCategoryQueryModel(object):

    def __init__(self):
        self._is_filter = None

    @property
    def is_filter(self):
        return self._is_filter

    @is_filter.setter
    def is_filter(self, value):
        self._is_filter = value


    def to_alipay_dict(self):
        params = dict()
        if self.is_filter:
            if hasattr(self.is_filter, 'to_alipay_dict'):
                params['is_filter'] = self.is_filter.to_alipay_dict()
            else:
                params['is_filter'] = self.is_filter
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniCategoryQueryModel()
        if 'is_filter' in d:
            o.is_filter = d['is_filter']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceIotWifiResultQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceIotWifiResultQueryResponse, self).__init__()
        self._result_type = None
        self._ssid = None

    @property
    def result_type(self):
        return self._result_type

    @result_type.setter
    def result_type(self, value):
        self._result_type = value
    @property
    def ssid(self):
        return self._ssid

    @ssid.setter
    def ssid(self, value):
        self._ssid = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceIotWifiResultQueryResponse, self).parse_response_content(response_content)
        if 'result_type' in response:
            self.result_type = response['result_type']
        if 'ssid' in response:
            self.ssid = response['ssid']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class JobWorthPositionInfo(object):

    def __init__(self):
        self._age = None
        self._benefit = None
        self._certifications = None
        self._company_certificate = None
        self._company_logo_afts_id = None
        self._company_name = None
        self._count = None
        self._education = None
        self._gender = None
        self._ka_position_id = None
        self._position_desc = None
        self._position_id = None
        self._position_job_id = None
        self._position_job_name = None
        self._position_profession_id = None
        self._position_property = None
        self._position_status = None
        self._position_title = None
        self._salary_max = None
        self._salary_min = None
        self._salary_type = None
        self._salary_unit = None
        self._skill_tag = None
        self._skip_url = None
        self._work_city = None
        self._work_longitude = None
        self._work_region = None
        self._work_year = None

    @property
    def age(self):
        return self._age

    @age.setter
    def age(self, value):
        self._age = value
    @property
    def benefit(self):
        return self._benefit

    @benefit.setter
    def benefit(self, value):
        self._benefit = value
    @property
    def certifications(self):
        return self._certifications

    @certifications.setter
    def certifications(self, value):
        self._certifications = value
    @property
    def company_certificate(self):
        return self._company_certificate

    @company_certificate.setter
    def company_certificate(self, value):
        self._company_certificate = value
    @property
    def company_logo_afts_id(self):
        return self._company_logo_afts_id

    @company_logo_afts_id.setter
    def company_logo_afts_id(self, value):
        self._company_logo_afts_id = value
    @property
    def company_name(self):
        return self._company_name

    @company_name.setter
    def company_name(self, value):
        self._company_name = value
    @property
    def count(self):
        return self._count

    @count.setter
    def count(self, value):
        self._count = value
    @property
    def education(self):
        return self._education

    @education.setter
    def education(self, value):
        self._education = value
    @property
    def gender(self):
        return self._gender

    @gender.setter
    def gender(self, value):
        self._gender = value
    @property
    def ka_position_id(self):
        return self._ka_position_id

    @ka_position_id.setter
    def ka_position_id(self, value):
        self._ka_position_id = value
    @property
    def position_desc(self):
        return self._position_desc

    @position_desc.setter
    def position_desc(self, value):
        self._position_desc = value
    @property
    def position_id(self):
        return self._position_id

    @position_id.setter
    def position_id(self, value):
        self._position_id = value
    @property
    def position_job_id(self):
        return self._position_job_id

    @position_job_id.setter
    def position_job_id(self, value):
        self._position_job_id = value
    @property
    def position_job_name(self):
        return self._position_job_name

    @position_job_name.setter
    def position_job_name(self, value):
        self._position_job_name = value
    @property
    def position_profession_id(self):
        return self._position_profession_id

    @position_profession_id.setter
    def position_profession_id(self, value):
        self._position_profession_id = value
    @property
    def position_property(self):
        return self._position_property

    @position_property.setter
    def position_property(self, value):
        self._position_property = value
    @property
    def position_status(self):
        return self._position_status

    @position_status.setter
    def position_status(self, value):
        self._position_status = value
    @property
    def position_title(self):
        return self._position_title

    @position_title.setter
    def position_title(self, value):
        self._position_title = value
    @property
    def salary_max(self):
        return self._salary_max

    @salary_max.setter
    def salary_max(self, value):
        self._salary_max = value
    @property
    def salary_min(self):
        return self._salary_min

    @salary_min.setter
    def salary_min(self, value):
        self._salary_min = value
    @property
    def salary_type(self):
        return self._salary_type

    @salary_type.setter
    def salary_type(self, value):
        self._salary_type = value
    @property
    def salary_unit(self):
        return self._salary_unit

    @salary_unit.setter
    def salary_unit(self, value):
        self._salary_unit = value
    @property
    def skill_tag(self):
        return self._skill_tag

    @skill_tag.setter
    def skill_tag(self, value):
        self._skill_tag = value
    @property
    def skip_url(self):
        return self._skip_url

    @skip_url.setter
    def skip_url(self, value):
        self._skip_url = value
    @property
    def work_city(self):
        return self._work_city

    @work_city.setter
    def work_city(self, value):
        self._work_city = value
    @property
    def work_longitude(self):
        return self._work_longitude

    @work_longitude.setter
    def work_longitude(self, value):
        self._work_longitude = value
    @property
    def work_region(self):
        return self._work_region

    @work_region.setter
    def work_region(self, value):
        self._work_region = value
    @property
    def work_year(self):
        return self._work_year

    @work_year.setter
    def work_year(self, value):
        self._work_year = value


    def to_alipay_dict(self):
        params = dict()
        if self.age:
            if hasattr(self.age, 'to_alipay_dict'):
                params['age'] = self.age.to_alipay_dict()
            else:
                params['age'] = self.age
        if self.benefit:
            if hasattr(self.benefit, 'to_alipay_dict'):
                params['benefit'] = self.benefit.to_alipay_dict()
            else:
                params['benefit'] = self.benefit
        if self.certifications:
            if hasattr(self.certifications, 'to_alipay_dict'):
                params['certifications'] = self.certifications.to_alipay_dict()
            else:
                params['certifications'] = self.certifications
        if self.company_certificate:
            if hasattr(self.company_certificate, 'to_alipay_dict'):
                params['company_certificate'] = self.company_certificate.to_alipay_dict()
            else:
                params['company_certificate'] = self.company_certificate
        if self.company_logo_afts_id:
            if hasattr(self.company_logo_afts_id, 'to_alipay_dict'):
                params['company_logo_afts_id'] = self.company_logo_afts_id.to_alipay_dict()
            else:
                params['company_logo_afts_id'] = self.company_logo_afts_id
        if self.company_name:
            if hasattr(self.company_name, 'to_alipay_dict'):
                params['company_name'] = self.company_name.to_alipay_dict()
            else:
                params['company_name'] = self.company_name
        if self.count:
            if hasattr(self.count, 'to_alipay_dict'):
                params['count'] = self.count.to_alipay_dict()
            else:
                params['count'] = self.count
        if self.education:
            if hasattr(self.education, 'to_alipay_dict'):
                params['education'] = self.education.to_alipay_dict()
            else:
                params['education'] = self.education
        if self.gender:
            if hasattr(self.gender, 'to_alipay_dict'):
                params['gender'] = self.gender.to_alipay_dict()
            else:
                params['gender'] = self.gender
        if self.ka_position_id:
            if hasattr(self.ka_position_id, 'to_alipay_dict'):
                params['ka_position_id'] = self.ka_position_id.to_alipay_dict()
            else:
                params['ka_position_id'] = self.ka_position_id
        if self.position_desc:
            if hasattr(self.position_desc, 'to_alipay_dict'):
                params['position_desc'] = self.position_desc.to_alipay_dict()
            else:
                params['position_desc'] = self.position_desc
        if self.position_id:
            if hasattr(self.position_id, 'to_alipay_dict'):
                params['position_id'] = self.position_id.to_alipay_dict()
            else:
                params['position_id'] = self.position_id
        if self.position_job_id:
            if hasattr(self.position_job_id, 'to_alipay_dict'):
                params['position_job_id'] = self.position_job_id.to_alipay_dict()
            else:
                params['position_job_id'] = self.position_job_id
        if self.position_job_name:
            if hasattr(self.position_job_name, 'to_alipay_dict'):
                params['position_job_name'] = self.position_job_name.to_alipay_dict()
            else:
                params['position_job_name'] = self.position_job_name
        if self.position_profession_id:
            if hasattr(self.position_profession_id, 'to_alipay_dict'):
                params['position_profession_id'] = self.position_profession_id.to_alipay_dict()
            else:
                params['position_profession_id'] = self.position_profession_id
        if self.position_property:
            if hasattr(self.position_property, 'to_alipay_dict'):
                params['position_property'] = self.position_property.to_alipay_dict()
            else:
                params['position_property'] = self.position_property
        if self.position_status:
            if hasattr(self.position_status, 'to_alipay_dict'):
                params['position_status'] = self.position_status.to_alipay_dict()
            else:
                params['position_status'] = self.position_status
        if self.position_title:
            if hasattr(self.position_title, 'to_alipay_dict'):
                params['position_title'] = self.position_title.to_alipay_dict()
            else:
                params['position_title'] = self.position_title
        if self.salary_max:
            if hasattr(self.salary_max, 'to_alipay_dict'):
                params['salary_max'] = self.salary_max.to_alipay_dict()
            else:
                params['salary_max'] = self.salary_max
        if self.salary_min:
            if hasattr(self.salary_min, 'to_alipay_dict'):
                params['salary_min'] = self.salary_min.to_alipay_dict()
            else:
                params['salary_min'] = self.salary_min
        if self.salary_type:
            if hasattr(self.salary_type, 'to_alipay_dict'):
                params['salary_type'] = self.salary_type.to_alipay_dict()
            else:
                params['salary_type'] = self.salary_type
        if self.salary_unit:
            if hasattr(self.salary_unit, 'to_alipay_dict'):
                params['salary_unit'] = self.salary_unit.to_alipay_dict()
            else:
                params['salary_unit'] = self.salary_unit
        if self.skill_tag:
            if hasattr(self.skill_tag, 'to_alipay_dict'):
                params['skill_tag'] = self.skill_tag.to_alipay_dict()
            else:
                params['skill_tag'] = self.skill_tag
        if self.skip_url:
            if hasattr(self.skip_url, 'to_alipay_dict'):
                params['skip_url'] = self.skip_url.to_alipay_dict()
            else:
                params['skip_url'] = self.skip_url
        if self.work_city:
            if hasattr(self.work_city, 'to_alipay_dict'):
                params['work_city'] = self.work_city.to_alipay_dict()
            else:
                params['work_city'] = self.work_city
        if self.work_longitude:
            if hasattr(self.work_longitude, 'to_alipay_dict'):
                params['work_longitude'] = self.work_longitude.to_alipay_dict()
            else:
                params['work_longitude'] = self.work_longitude
        if self.work_region:
            if hasattr(self.work_region, 'to_alipay_dict'):
                params['work_region'] = self.work_region.to_alipay_dict()
            else:
                params['work_region'] = self.work_region
        if self.work_year:
            if hasattr(self.work_year, 'to_alipay_dict'):
                params['work_year'] = self.work_year.to_alipay_dict()
            else:
                params['work_year'] = self.work_year
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = JobWorthPositionInfo()
        if 'age' in d:
            o.age = d['age']
        if 'benefit' in d:
            o.benefit = d['benefit']
        if 'certifications' in d:
            o.certifications = d['certifications']
        if 'company_certificate' in d:
            o.company_certificate = d['company_certificate']
        if 'company_logo_afts_id' in d:
            o.company_logo_afts_id = d['company_logo_afts_id']
        if 'company_name' in d:
            o.company_name = d['company_name']
        if 'count' in d:
            o.count = d['count']
        if 'education' in d:
            o.education = d['education']
        if 'gender' in d:
            o.gender = d['gender']
        if 'ka_position_id' in d:
            o.ka_position_id = d['ka_position_id']
        if 'position_desc' in d:
            o.position_desc = d['position_desc']
        if 'position_id' in d:
            o.position_id = d['position_id']
        if 'position_job_id' in d:
            o.position_job_id = d['position_job_id']
        if 'position_job_name' in d:
            o.position_job_name = d['position_job_name']
        if 'position_profession_id' in d:
            o.position_profession_id = d['position_profession_id']
        if 'position_property' in d:
            o.position_property = d['position_property']
        if 'position_status' in d:
            o.position_status = d['position_status']
        if 'position_title' in d:
            o.position_title = d['position_title']
        if 'salary_max' in d:
            o.salary_max = d['salary_max']
        if 'salary_min' in d:
            o.salary_min = d['salary_min']
        if 'salary_type' in d:
            o.salary_type = d['salary_type']
        if 'salary_unit' in d:
            o.salary_unit = d['salary_unit']
        if 'skill_tag' in d:
            o.skill_tag = d['skill_tag']
        if 'skip_url' in d:
            o.skip_url = d['skip_url']
        if 'work_city' in d:
            o.work_city = d['work_city']
        if 'work_longitude' in d:
            o.work_longitude = d['work_longitude']
        if 'work_region' in d:
            o.work_region = d['work_region']
        if 'work_year' in d:
            o.work_year = d['work_year']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ItemLabelCreateInfo(object):

    def __init__(self):
        self._label_key = None
        self._label_value = None

    @property
    def label_key(self):
        return self._label_key

    @label_key.setter
    def label_key(self, value):
        self._label_key = value
    @property
    def label_value(self):
        return self._label_value

    @label_value.setter
    def label_value(self, value):
        self._label_value = value


    def to_alipay_dict(self):
        params = dict()
        if self.label_key:
            if hasattr(self.label_key, 'to_alipay_dict'):
                params['label_key'] = self.label_key.to_alipay_dict()
            else:
                params['label_key'] = self.label_key
        if self.label_value:
            if hasattr(self.label_value, 'to_alipay_dict'):
                params['label_value'] = self.label_value.to_alipay_dict()
            else:
                params['label_value'] = self.label_value
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ItemLabelCreateInfo()
        if 'label_key' in d:
            o.label_key = d['label_key']
        if 'label_value' in d:
            o.label_value = d['label_value']
        return o


